/*
GLOBAL STYLES, FONTS & RESETS
*/
@font-face{
  font-family:'Default Font';
  src:url('./fonts/Inter-Regular.woff2') format('woff2'),
    url('./fonts/Inter-Regular.woff') format('woff');
  font-weight:400;
  font-style:normal;
  font-display:swap;
}
@font-face{
  font-family:'Default Font';
  src:url('./fonts/Inter-Medium.woff2') format('woff2'),
    url('./fonts/Inter-Medium.woff') format('woff');
  font-weight:500;
  font-style:normal;
  font-display:swap;
}
@font-face{
  font-family:'Default Font';
  src:url('./fonts/Inter-SemiBold.woff2') format('woff2'),
    url('./fonts/Inter-SemiBold.woff') format('woff');
  font-weight:600;
  font-style:normal;
  font-display:swap;
}
@font-face{
  font-family:'Default Font';
  src:url('./fonts/Inter-Bold.woff2') format('woff2'),
    url('./fonts/Inter-Bold.woff') format('woff');
  font-weight:700;
  font-style:normal;
  font-display:swap;
}
html{
  min-height:100%;
  font-size:1rem;
}
body{
  background-color:var(--theme-body-background-color);
  overflow-x:hidden;
  font-size:var(--theme-font-size);
}
*{
  padding:0;
  margin:0;
  border:none;
  border-style:solid;
  border-width:0;
  border-color:var(--theme-border-color);
  box-sizing:border-box;
}
*::before,
*::after{
  box-sizing:border-box;
}
table{
  border-collapse:collapse;
}
br{
  clear:both;
}
ul{
  list-style-type:none;
}
a{
  color:var(--theme-link-color);
  text-decoration:none;
}
a:hover{
  color:var(--theme-link-color-hover);
  text-decoration:none;
}
*{
  font-family:var(--theme-font-family);
}
*[dir="rtl"]{
  direction:rtl;
  unicode-bidi:embed;
}
div,
td{
  color:var(--theme-font-color);
  line-height:150%;
  text-align:left;
  font-weight:400;
}
div, td, button, input, select, textarea{
  letter-spacing:0.8px;
}
*[dir="rtl"] div,
*[dir="rtl"] td{
  direction:rtl;
  unicode-bidi:embed;
  text-align:right;
}
h1{
  font-family:var(--theme-heading-font-family);
  font-size:var(--theme-headline-size-large);
  margin-bottom:0.625rem;
  line-height:130%;
  font-weight:500;
}
h2,
h3,
h4{
  font-family:var(--theme-heading-font-family);
  color:var(--theme-headline-color);
  font-weight:normal;
}
h2, h3{
  font-size:var(--theme-headline-size-medium);
  padding:.4em 0;
}
h4{
  font-size:var(--theme-font-size);
  font-weight:700;
}
h3.sep{
  display:block;
  overflow:hidden;
  margin-bottom:1em;
  height:1em;
}
h3.sep > span{
  display:block;
  overflow:hidden;
  position:absolute;
  padding:0.3125rem 0.625rem 0.3125rem 0;
  font-weight:600 !important;
}
[dir="rtl"] h3.sep > span{
  padding:0.3125rem 0 0.3125rem 0.625rem;
}
h4{
  font-weight:400;
  border-bottom:0.0625rem solid var(--theme-border-color);
  padding:.5em 0 .5em 0;
  margin-bottom:0.625rem;
  font-size:110%;
}
/* Prevents users from selecting contents */
.noselect{
  -moz-user-select:none;
  -webkit-user-select:none;
  -webkit-touch-callout:none;
  -ms-user-select:none;
  user-select:none;
}
/* Global member photos and icons */
img.main{
  max-width:31.25rem;
  max-height:31.25rem;
}
img.thumb_normal{
  max-width:8.75rem;
  max-height:10rem;
}
img.thumb_profile{
  max-width:12.5rem;
  max-height:12.5rem;
	object-fit:cover;
  object-position:top center;
}
img.thumb_icon,
.bg_thumb_icon{
  width:3rem;
  height:3rem;
	border-radius:3.125rem;
}
img.main,
img.thumb_normal,
img.thumb_profile,
img.thumb_icon{
  border:0.0625rem solid var(--theme-border-color);
}
.bg_item_photo{
  border-width:0;
}
/*GENERAL LAYOUT*/
#global_content .layout_main{
  gap:10px;
}
.generic_layout_container > h3,
.generic_layout_container > h2,
.layout_content > h2,
.layout_content > h3{
  border-bottom-width:1px;
  background-color:var(--theme-list-background-color);
  border-radius:var(--theme-widget-radius) var(--theme-widget-radius) 0 0;
  font-family:var(--theme-heading-font-family);
  font-size:var(--theme-headline-size-medium);
  margin:-0.9375rem -0.9375rem 0.9375rem;
  padding:0.9375rem;
  position:relative;
  font-weight:500 !important;
}
.layout_middle .generic_layout_container > h3,
.layout_middle .generic_layout_container > h2{
  background-color:inherit;
}
.layout_left, 
.layout_right,
.layout_middle{
  padding:0 0.625rem 0.625rem;
}
.layout_top .layout_middle{
  padding-bottom:0;
}
.layout_left > div > .generic_layout_container, 
.layout_right > div > .generic_layout_container,
.layout_middle > .generic_layout_container,
.layout_core_container_tabs > .generic_layout_container,
.layout_content,
.block{
  border-radius:var(--theme-widget-radius) !important;
  background:var(--theme-list-background-color);
  border-width:0.0625rem;
  box-shadow:var(--theme-layout-box-shadow);
}
html.dark_mode .layout_core_container_tabs > .generic_layout_container,
html.dark_mode .layout_content{
  background:var(--theme-list-background-color) !important;
}
.layout_left > div > .generic_layout_container, 
.layout_right > div > .generic_layout_container,
.layout_middle > .generic_layout_container,
.layout_core_container_tabs > .generic_layout_container,
.layout_content{
  margin-bottom:var(--theme-widget-spacing);
  padding:0.9375rem;
}
.layout_left > div > .generic_layout_container, 
.layout_right > div > .generic_layout_container{
  box-shadow:var(--theme-layout-box-shadow);
}
#global_wrapper .layout_middle > .layout_core_container_tabs{
  border-width:0;
  box-shadow:none !important;
  background:none !important;
  padding:0 !important;
}
.layout_core_container_tabs > .generic_layout_container > h3{
  display:none;
}
.layout_left{
  width:var(--theme-content-columns-left-width);
}
.layout_middle{
  flex:1;
}
.layout_right{
  width:var(--theme-content-columns-right-width);
}
#global_wrapper{
  text-align:center;
  padding-top:var(--theme-widget-spacing);
  position:relative;
}
#global_content{
  min-height:31.25rem;
  box-sizing:border-box;
  margin:0 auto;
  width:var(--theme-content-width);
}
#global_content_simple{
  display:inline-block;
  overflow:hidden;
}
/* No Result */
.activity_noresult_tip.block{
  border:0;
}
@media (max-width:1199px){
  #global_wrapper{
    margin:0;
  }
}
/* Header */
.layout_page_header{
  background-color:var(--theme-header-background-color);
  position:fixed;
  top:0;
  right:0;
  left:0;
  z-index:9;
  box-shadow:0 0.0625rem 0.1875rem rgba(17, 24, 39, .1);
}
.layout_page_header .layout_main{
  /* max-width:var(--theme-content-width); */
  margin:0 auto;
}
.pulse_header{
  height:var(--theme-header-height);
  position:relative;
  z-index:999;
}
.pulse_header_inner{
  display:flex;
  align-items:center;
  justify-content:flex-start;
  max-width:100%;
  /* padding:0 25px; */
  gap:var(--theme-header-inner-spacing);
  height:100%;
}
.header_left{
  display:flex;
  align-items:center;
  gap:var(--theme-header-inner-spacing);
  width:30%;
  white-space:nowrap;
}
/*Header Logo*/
.header_logo_contrast,
.dark_mode .header_logo,
.light_mode .header_logo{
  display:none;
}
.dark_mode .header_logo_contrast,
.light_mode .header_logo_contrast{
  display:block;
}
.header_logo a,
.header_logo_contrast a{
  font-size:1.4rem;
  font-weight:600 !important;
}
.header_logo a:hover,
.header_logo_contrast:hover{
  text-decoration:none;
}
.header_logo img{
  max-width:100%;
  max-height:2.875rem;
}
.header_logo_contrast img{
  width:100%;
  max-height:2.875rem;
}
/*Header Search*/
.header_search_wrap{
  flex:1;
}
.header_search{
  margin-left:0.9375rem;
}
[dir="rtl"] .header_search{
  margin-left:0;
  margin-right:0.9375rem;
}
.layout_core_search_mini #global_search_form{
  padding:0;
  position:relative;
  margin:auto;
  background:none !important;
}
.layout_core_search_mini #global_search_field{
  background-color:var(--theme-header-search-background-color);
  border:0.6px solid var(--theme-input-border-color) !important;
  outline:none;
  border-width:0;
  padding:10px 15px 10px 40px;
  border-radius:0.625rem;
  padding-right:2.375rem;
  min-height:2.5rem;
  color:var(--theme-header-search-font-color);
  width:100%;
  transition:0.5s; 
}
.layout_core_search_mini #global_search_field::placeholder{
  font-size:14px;
  font-weight:400;
  color:var(--theme-font-color-light);
}
/* [dir="rtl"] .layout_core_search_mini #global_search_field{
  padding-right:0.9375rem;
  padding-left:2.375rem;
} */
.layout_core_search_mini #global_search_form button{
  background-color:transparent;
  border-width:0;
  color:var(--theme-header-search-background-color);
  height:2.375rem;
  width:2.375rem;
  font-size:16px;
  border-width:0 !important;
  top:50%;
  left:5px;
  transform:translateY(-50%);
}
[dir="rtl"] .layout_core_search_mini #global_search_form button{
  left:auto;
  right:5px;
}
.layout_core_search_mini #global_search_form button *{
  color:var(--theme-font-color-light) !important;
}
.header_mini_search{
  width:15.625rem;
}

/*Mini Menu*/
.header_right{
  width:35%;
  display:flex;
  justify-content:flex-end;
  align-items:center;
}
.layout_core_menu_mini{
  display:flex;
  justify-content:space-between;
  align-items:center;
}
#core_menu_mini_menu > ul{
  display:flex;
  align-items:center;
  justify-content:flex-end;
}
/* .guest-user #core_menu_mini_menu > ul{   
  min-width:10.3125rem;
} */
#core_menu_mini_menu > ul > li{
  margin-left:0.625rem;
  position:relative;
  text-align:center !important;
  /* min-width:3.125rem; */
}
[dir="rtl"] #core_menu_mini_menu > ul > li{
  margin-left:0;
  margin-right:0.625rem;
  text-align:center !important;
}
.guest-user #core_menu_mini_menu > ul > li{   
  min-width:inherit;
}
#core_menu_mini_menu > ul > li a.show_icons{
  display:flex;
  align-items:center;
  justify-content:center;
  flex-direction:column;
  color:var(--pulse-minimenu-links-color);
  background-color:var(--pulse-minimenu-background-color);
  width:45px !important;
  height:45px !important;
  border-radius:50%;
  padding:0;
}
#core_menu_mini_menu > ul > li a.show_icons:hover{
  color:var(--pulse-minimenu-links-hover-color);
  background-color:var(--pulse-minimenu-background-hover-color);
  text-decoration:none;
  height:45px;
  width:45px;
  border-radius:50%;
  opacity:1;
  transition:all 0.6s ease;
}
#core_menu_mini_menu > ul > li a.show_icons:hover i{
  opacity:1;
}
#core_menu_mini_menu > ul > li.core_mini_menu_profile > a > .bg_thumb_icon{
  border-width:0;
  border-radius:50%;
  margin:0;
  height:1.75rem;
  width:1.75rem;
}
#core_menu_mini_menu > ul > li.core_mini_menu_profile > a > .bg_thumb_icon:before{
  font-size:0.75rem;
}
#core_menu_mini_menu > ul > li.core_mini_menu_profile > a .icon_down{
  display:none !important;
}
#core_menu_mini_menu > ul > li.core_mini_menu_profile > a ._linktxt:after{
  content:"\f0dd";
  font-family:'Font Awesome 6 Free';
  font-weight:700;
  margin-left:0.1875rem;
  line-height:0;
  position:relative;
  top:-0.0625rem;
}
[dir="rtl"] #core_menu_mini_menu > ul > li.core_mini_menu_profile > a ._linktxt:after{
  margin-left:0;
  margin-right:0.1875rem;
}
#core_menu_mini_menu > ul > li.core_mini_menu_profile a.show_icons i{
  font-weight:700;
}
#core_menu_mini_menu > ul > li a:focus-visible{
  outline:0;
}
#core_menu_mini_menu > ul > li a.show_icons i{  
  font-weight:400;
  padding:0 !important;
  display:flex;
  align-items:center;
  justify-content:center;
  height:1.5625rem !important;
  margin:0;
  opacity:0.7;
  width:100%;
}
#core_menu_mini_menu > ul > li .show_icons i.minimenu_icon:before{
  font-size:1.5rem !important;
  padding:0;
  border-radius:0;
  display:flex;
  justify-content:center;
  align-items:center;
}
#core_menu_mini_menu > ul > li a.show_icons span._linktxt{
  font-size:var(--theme-menu-link-size);
  font-family:var(--theme-header-menu-font-family);
  display:flex !important;
  white-space:nowrap;
  align-items:center;
  display:none !important;
}
#core_menu_mini_menu > ul .core_mini_auth.show_icons,
#core_menu_mini_menu > ul .core_mini_signup.show_icons{
  padding:8px 12px !important;
  border-radius:12px !important;
  height:auto !important;
  width:auto !important;
}
#core_menu_mini_menu > ul .core_mini_signup.show_icons{
  color:var(--theme-button-font-color) !important;
  background-color:var(--theme-button-background-color) !important;
  border:0.0625rem solid var(--theme-button-border-color) !important;
}
#core_menu_mini_menu > ul .core_mini_auth.show_icons{
  color:var(--theme-color) !important;
  background-color:var(--theme-list-background-color) !important;
  border:0.0625rem solid var(--theme-color) !important;
}
#core_menu_mini_menu > ul .core_mini_auth.show_icons:hover,
#core_menu_mini_menu > ul .core_mini_signup.show_icons:hover{
  color:var(--theme-button-font-color-hover) !important;
  background-color:var(--theme-button-background-color-hover) !important;
  border-color:var(--theme-button-border-color-hover) !important;
}
/* html.dark_mode #core_menu_mini_menu > ul .core_mini_signup.show_icons{
  color:var(--pulse-minimenu-links-hover-color) !important;
}
html.dark_mode #core_menu_mini_menu > ul .core_mini_auth.show_icons{
  color:var(--pulse-button-font-color);
  border-color:var(--pulse-button-border-color) !important;
  background-color:var(--pulse-button-background-color);
} */
#core_menu_mini_menu > ul .core_mini_signup.show_icons:hover{
  color:var(--pulse-button-font-color-hover);
  background-color:var(--pulse-button-background-color-hover);
  border:var(--theme-border-width) solid var(--pulse-button-border-color-hover) !important;
  border-radius:12px !important;
}
#core_menu_mini_menu > ul .core_mini_auth.show_icons span._linktxt, 
#core_menu_mini_menu > ul .core_mini_signup.show_icons span._linktxt{
  display:block !important;
  font-weight:500 !important;
}
#core_menu_mini_menu > ul .core_mini_auth.show_icons .minimenu_icon.fi.fi-rr-sign-in-alt{
  display:none;
}
#core_menu_mini_menu > ul .core_mini_signup.show_icons .minimenu_icon.fi.fi-rr-user-add{
  display:none;
}
.core_mini_menu_accessibility .core_settings_dropdown{
  margin-left:-15.8125rem;
}
[dir="rtl"] .core_mini_menu_accessibility .core_settings_dropdown{
  margin-left:auto;
  margin-right:-11.25rem;
}
.layout_core_menu_mini #core_menu_mini_menu > ul > li.core_mini_language .language_btn{
  border-width:0 !important;
  padding:0.625rem 0 0.3125rem !important;
  padding:0 !important;
  color:var(--pulse-minimenu-links-color) !important;
  background-color:var(--pulse-minimenu-background-color) !important;
  border-radius:50%;
}
.layout_core_menu_mini #core_menu_mini_menu > ul > li.core_mini_language .language_btn:hover{
  color:var(--pulse-minimenu-links-hover-color) !important;
  background-color:var(--pulse-minimenu-background-hover-color) !important;
}
html .header_menu_mini .layout_core_menu_mini #core_menu_mini_menu > ul > li.core_mini_language .language_btn > i{
  height:1.5625rem !important;
  margin:0 !important;
}
html .header_menu_mini .layout_core_menu_mini #core_menu_mini_menu > ul > li.core_mini_language .language_btn > i::before{
  font-size:1.5rem;
}
.header_mobile_menu{
  display:none;
}
/*Count Bubble*/
.minimenu_update_count_bubble,
.minimenu_message_count_bubble{
  min-width:20px;
  height:auto;
  text-align:center !important;
  padding:5px 5px;
  margin-left:0;
  left:50%;
  margin-top:0.125rem !important;
  z-index:1;
  top:0;
  font-size:11px;
  line-height:1;
}
[dir="rtl"] .minimenu_update_count_bubble,
[dir="rtl"] .minimenu_message_count_bubble{
  margin-left:auto;
  margin-right:0;
  right:50%;
  left:auto;
}
.minimenu_update_count_bubble_active,
.minimenu_message_count_bubble{
  display:block;
}
/*Mini Menu Pulldown*/
.header_menu_mini .pulldown_contents_wrapper{
  right:0;
  margin-right:0 !important;
  margin-left:0 !important;
}
[dir="rtl"] .header_menu_mini .pulldown_contents_wrapper{
  right:auto;
  left:0;
}
.core_pulldown_header{
  font-size:var(--theme-headline-size-medium);
  font-weight:600 !important;
  border:0;
  padding:0.75rem;
}
.core_pulldown_header > a{
  color:var(--theme-font-color);
}
.pulldown_contents > ul > li:hover{
  background-color:var(--theme-pulldown-contents-list-background-color-hover) !important;
  transition:var(--theme-item-transition);
}
.header_menu_mini .pulldown_contents_wrapper,
.core_settings_dropdown{
  margin-top:3rem;
}
.pulldown_contents_wrapper{
  border-radius:var(--theme-dropdown-radius);
  box-shadow:var(--theme-dropdown-box-shadow);
  filter:none;
  border-width:var(--theme-border-width);
  width:23.75rem;
  max-width:23.75rem;
  overflow:hidden;
}
.pulldown_contents > ul > li + li{
  border:0;
}
.pulldown_options a + a{
  border:0;
}
.pulldown_contents > ul > li{
  padding:15px 20px;
}
.notification_item_photo{
  margin-right:0.9375rem;
}
.messages_menu > li .pulldown_item_photo{
  margin-right:0.9375rem;
}
.notifications_item_delete{
  right:25px;
}
.pulldown_options a{
  padding:12px 0;
}

/* Minimenu Dropdown */
.header_minimenu_icon{
  min-width:3.125rem;
  display:flex;
  justify-content:center;
  align-items:center;
}
.header_minimenu_icon i{
  font-size:1.375rem;
  display:flex;
  justify-content:center;
  align-items:center;
  height:45px;
  width:45px;
  opacity:0.7;
  color:var(--pulse-minimenu-links-color);
  background-color:var(--pulse-minimenu-background-color);
  transition:0.6s;
  border-radius:50%;
}
.header_minimenu_icon:hover i{
  opacity:1;
  color:var(--pulse-minimenu-links-hover-color);
  background-color:var(--pulse-minimenu-background-hover-color);
}
.pulse_header_mainmenu_dropdown{
  top:5px !important;
  right:0px !important;
  max-height:calc(95vh - var(--theme-header-height) - 55px);
  overflow-y:hidden;
  padding:15px 5px 15px 15px;
  background-color:#F0F0F0;
  background-color:var(--theme-list-background-color-alt);
  border-radius:var(--theme-dropdown-radius);
  box-shadow:rgba(0, 0, 0, 0.35) 0px 5px 15px;
  transition:max-height 0.3s ease, padding 0.2s ease;
  z-index:999;
}
[dir="rtl"] .pulse_header_mainmenu_dropdown{
  left:0px !important;
  right:auto !important;
}
html.dark_mode .pulse_header_mainmenu_dropdown{
  border:var(--theme-border-width) solid var(--theme-border-color);
  background-color:var(--theme-body-background-color);
}
.pulse_header_mainmenu_dropdown_inner{
  overflow:auto;
  max-height:calc(95vh - var(--theme-header-height) - 70px);
  padding-right:10px;
}
.pulse_header_mainmenu_dropdown_header{
  position:sticky;
  top:0;
  z-index:99;
  padding:0 0 15px;
  background-color:var(--theme-list-background-color-alt);
}
html.dark_mode .pulse_header_mainmenu_dropdown_header{
  background-color:var(--theme-body-background-color);
}
.pulse_header_mainmenu_dropdown_heading{
  font-size:22px;
  font-weight:600;
  margin-bottom:0;
  padding-bottom:0;
  color:var(--theme-font-color);
}
.pulse_header_mainmenu_dropdown_body{
  display:flex;
  align-items:flex-start;
  justify-content:space-between;
  gap:35px;
  padding:0 20px 15px;
}
.pulse_header_mainmenu{
  width:400px;
  padding:20px;
  border-radius:12px;
  background-color:#ffffff;
  background-color:var(--theme-list-background-color);
  padding:0;
  position:sticky;
  top:0;
  left:0;
}
[dir="rtl"] .pulse_header_mainmenu{
  border-radius:0px 12px 12px 0px;
}
.pulse_header_mainmenu_input{
  position:relative;
  margin:20px;
}
[dir="rtl"] .pulse_header_mainmenu_input{
  flex-direction:row-reverse;
}
.pulse_header_mainmenu_input i{
  position:absolute;
  top:50%;
  transform:translateY(-50%);
  left:15px;
  font-size:16px;
}
[dir="rtl"] .pulse_header_mainmenu_input i{
  left:auto;
  right:15px;
}
.pulse_header_mainmenu_input input[type=text]{
  border:0;
  background:var(--theme-header-search-background-color);
  color:var(--theme-header-search-font-color);
  padding:0px 0px 0px 40px;
  border-radius:22px;
  height:42px;
  width:100%;
}
[dir="rtl"] .pulse_header_mainmenu_input input[type=text]{
  padding:0px 40px 0px 0px;
}
.pulse_header_mainmenu_input input[type=text]::placeholder{
  font-size:15px;
  font-weight:400;
}
.pulse_header_mainmenu_item_container{
  overflow-y:auto;
  padding-inline:10px;
  padding-bottom:10px;
  display:flex;
  flex-direction:column;
  gap:10px;
}
.dashboardmenu_head{
  font-size:var(--theme-headline-size-medium);
  font-weight:600;
  padding:0px 0px 0px 10px;
  margin-bottom:20px;
  color:var(--theme-font-color);
}
.pulse_header_mainmenu_item_link{
  display:flex;
  justify-content:flex-start;
  align-items:center;
  gap:15px;
  padding:10px;
}
.pulse_header_mainmenu_item_link:hover{
  border-radius:var(--theme-item-radius);
  background:var(--theme-list-background-color-hover);
}
.pulse_header_mainmenu_item_icon{
  height:40px;
  width:40px;
  aspect-ratio:1;
  display:flex;
  justify-content:center;
  align-items:center;
}
.pulse_header_mainmenu_item_icon img{
  height:100%;
}
.pulse_header_mainmenu_item_icon i{
  border-radius:50%;
  background-color:var(--theme-list-background-color-alt);
  height:100%;
  width:100%;
  font-size:20px;
  display: flex;
  align-items: center;
  justify-content: center;
}
.pulse_header_mainmenu_item_content{
  flex:1;
}
.pulse_header_mainmenu_item_content h4{
  font-size:var(--pulse-body-fontsize);
  font-weight:600;
  padding:0 0 5px 0px;
  margin:0;
  border:0;
  color:var(--theme-font-color);
}
.pulse_header_mainmenu_item_content p{
  font-size:var(--theme-font-size-small);
  font-weight:400;
  margin:0;
  line-height:150%;
  color:var(--theme-font-color-light);
}
.createmenu_dropdown{
  min-width:250px;
  padding:20px 10px;
  border-radius:12px;
  background-color:#ffffff;
  background-color:var(--theme-list-background-color);
  position:sticky;
  top:40px;
  left:0;
}
[dir="rtl"] .createmenu_dropdown{
  border-radius:12px 0px 0px 12px;
}
.createmenu_head{
  margin:0px 0px 15px 0px;
  padding:0px 10px;
}
.createmenu_dropdown_heading{
  font-size:var(--theme-font-size-small);
  font-weight:500;
  padding:0;
  color:var(--theme-font-color);
}
.createmenu_dropdown_item{
  display:flex;
  justify-content:flex-start;
  align-items:center;
  gap:10px;
  padding:10px;
}
.createmenu_dropdown_item:hover{
  border-radius:var(--theme-item-radius);
  background-color:var(--theme-list-background-color-hover);
}
.createmenu_dropdown_item_image{
  width:40px;
  aspect-ratio:1;
}
.createmenu_dropdown_item_image img{
  width:100%;
  height:100%;
}
.createmenu_dropdown_item_image i{
  height:40px;
  width:40px;
  display:flex;
  justify-content:center;
  align-items:center;
  border-radius:50%;
  background-color:var(--theme-secondary-button-background-color);
}
.createmenu_dropdown_item:hover .createmenu_dropdown_item_image i{
  background:transparent;
}
.createmenu_dropdown_item_content p{
  font-size:var(--theme-font-size-small);
  font-weight:500;
  margin:0;
  color:var(--theme-font-color);
}
@media (max-width:600px){
  html #pulse_header_mainmenu_dropdown.dropdown-menu{
    top:145px !important;
  }
}
@media (max-width:767px){
  #pulse_header_mainmenu_dropdown.dropdown-menu{
    position:fixed !important;
    top:85px !important;
    left:0 !important;
    right:0 !important;
    width:95% !important;
    transform:none !important;
    min-width:95% !important;
    margin-inline:auto !important;
  }
  .pulse_header_mainmenu_dropdown_body{
    flex-direction:column !important;
    padding:0px 5px 20px;
  }
  .pulse_header_mainmenu,
  .createmenu_dropdown{
    width:100% !important;
    min-width:100% !important;
    position:relative !important;
    top:0 !important;
    border-radius:var(--theme-item-radius);
    border-radius:12px !important;
  }
}
@media(min-width:767px) and (max-width:1004px){
  [dir="rtl"] .pulse_header_mainmenu_dropdown{
    left:0px !important;
    right:0px !important;
  }
}

/* Profile Setting Dropdown */
.core_settings_dropdown > ul > li > a, 
.core_settings_dropdown > ul > li > *{
  padding:0.625rem 0.9375rem;
}
.core_settings_dropdown{
  border-radius:var(--theme-dropdown-radius) !important;
  box-shadow:var(--theme-dropdown-box-shadow);
  filter:none;
  border-width:var(--theme-border-width);
  width:18.75rem;
}
.core_settings_dropdown > ul > li i.menuicon{
  margin-right:10px;
}
.core_settings_dropdown > ul > li i.menuicon:before, 
.core_settings_dropdown > ul > li a i.menuicon span:before{
  font-size:16px;
}
.dropdown-menu{
  border-radius:var(--theme-dropdown-radius);
  box-shadow:var(--theme-dropdown-box-shadow);
  border-width:var(--theme-border-width);
}
.dropdown-menu .dropdown-item{
  padding-block:10px;
  font-size:var(--theme-font-size);
}
.dropdown-menu .dropdown-divider{
  display:none;
}
/*Main Menu*/
/* .pulse_main_menu{
  padding-right:0.75rem;
  border-right-width:0.0625rem;
}
[dir="rtl"] .pulse_main_menu{
  padding-right:0;
  padding-left:0.75rem;
  border-right-width:0;
  border-left-width:0.0625rem;
}
.main_navigation .mobile_menu_close{
  display:none;
}
.main_navigation{
  background-color:var(--theme-header-menu-background-color);
  border-inline-end-width:1px;
  position:fixed;
  left:0;
  bottom:0;
  top:71px;
  overflow-x:auto;
  overflow-y:auto;
  height:calc(100vh - var(--theme-header-height));
  width:var(--theme-sidebar-width);
  transition:0.4s;
  z-index:99;
  padding-top:20px;
  display:flex;
  flex-direction:column;
  justify-content:space-between;
}
[dir="rtl"] .main_navigation{
  left:auto;
  right:0;
}
.main_navigation_inner{
  display:flex;
  flex-direction:column;
  justify-content:space-between;
  height:calc(100vh - var(--theme-header-height));
  width:calc(var(--theme-sidebar-width) - 9px);
}
.main_navigation .main_navigation_menu.header-nav-open{
  left:0;
}
[dir="rtl"] .main_navigation .main_navigation_menu{
  left:auto; 
  right:-18.75rem;
}
[dir="rtl"] .main_navigation .main_navigation_menu.header-nav-open{
  left:auto;
  right:0;
}
.pulse_main_menu .main_navigation_menu li > a{
  display:block;
  padding:16px;
  font-size:1rem;
  border-radius:10px;
  margin-left:8px;
  color:var(--theme-header-menu-link-color);
  font-family:var(--pulse-mainmenu-fontfamily);
  position:relative;
}
.pulse_main_menu.pulse_issubmenu .main_navigation_menu li > a .fa.fa-angle-down{
  float:right;
  transition:all 0.5s ease;
  display:block;
  height:100%;
  width:30px;
  display:flex;
  justify-content:center;
  align-items:center;
  position:absolute;
  top:0px;
  right:15px;
}
[dir="rtl"] .pulse_main_menu.pulse_issubmenu .main_navigation_menu li > a .fa.fa-angle-down{
  float:left;
  left:0;
  right:auto;
}
.pulse_main_menu.pulse_isnotsubmenu .main_navigation_menu li > a .fa.fa-angle-down{
  display:none;
}
.pulse_main_menu.pulse_issubmenu .main_navigation_menu li > a.open_toggle_menu .fa.fa-angle-down{
  rotate:calc(180deg);
}
.pulse_main_menu.pulse_issubmenu .main_navigation_menu li .main_menu_submenu{
  display:none;
  width:100%;
  background:var(--theme-list-background-color);
  padding:0;
}
.pulse_main_menu.pulse_issubmenu .main_navigation_menu li .main_menu_submenu > li > a{
  padding:16px 20px 16px 40px;
}
.pulse_main_menu.pulse_isnotsubmenu .main_navigation_menu li .main_menu_submenu{
  display:none;
}
.pulse_main_menu .main_navigation_menu li > a > span{
  font-family:var(--pulse-mainmenu-fontfamily);
}
.pulse_main_menu .main_navigation_menu li > a > i{
  margin-right:0.3125rem;
}
[dir="rtl"] .pulse_main_menu .main_navigation_menu li > a > i{
  margin-right:0;
  margin-left:0.3125rem;
}
.pulse_main_menu .main_navigation_menu li.active > a,
.pulse_main_menu .main_navigation_menu li.active > a *{
  color:var(--theme-header-menu-link-color) !important;
  text-decoration:none;
  font-weight:500;
}
.pulse_main_menu .main_navigation_menu li:hover > a{
  color:var(--theme-header-menu-link-hover-color) !important;
  text-decoration:none;
  background-color:var(--theme-list-background-color-hover);
  font-weight:500;
}
.pulse_main_menu .main_navigation_menu li.active > a > i,
.pulse_main_menu .main_navigation_menu li.active > a > i *{
  font-weight:600;
}
.pulse_main_menu .main_navigation_menu li:hover > a > i{
  font-weight:600;
}
.main_navigation::-webkit-scrollbar{
  width:0;
}
.main_navigation:hover::-webkit-scrollbar{
  width:8px;
}
.main_navigation::-webkit-scrollbar-track{
  width:0px;
  background:#fff;
}
.main_navigation::-webkit-scrollbar-thumb{
  width:8px;
  border-radius:100px;
  background:#9ca3af;
} */

/* Footer */
#global_footer{
  border-top-width:1px;
  background-color:var(--theme-footer-background-color);
  width:auto;
  float:none;
  padding-inline:10px;
}
.layout_page_footer{
  margin:0px auto 0;
}
.pulse_footer{
  padding:1.875rem 0 0;
}
.pulse_footer_row{
  display:flex;
  justify-content:space-between;
}
.pulse_footer_right_row{
  display:flex;
  justify-content:space-between;
}
.pulse_footer_logo,
.pulse_footer_logo_contrast{
  margin-bottom:1.125rem;
}
.pulse_footer_logo_contrast,
.dark_mode .pulse_footer_logo,
.light_mode .pulse_footer_logo{
  display:none;
}
.dark_mode .pulse_footer_logo_contrast,
.light_mode .pulse_footer_logo_contrast{
  display:block;
}
.pulse_footer_logo img,
.pulse_footer_logo_contrast img{
  max-width:100%;
  max-height:3.125rem;
}
.pulse_footer_left .layout_core_menu_logo a{
  font-size:1.6em;
  font-weight:600 !important;
}
.pulse_footer_left .layout_core_menu_logo a:hover{
  text-decoration:none;
}
.pulse_footer_left p{
  margin-bottom:0;
  line-height:1.8;
}
.footer_social_links{
  margin-top:0.625rem;
}
.footer_social_links h6{
  font-weight:600 !important;
  color:var(--theme-footer-font-color);
  display:none;
}
.footer_social_links .navigation{
  display:flex;
  align-items:center;
  justify-content:flex-start;
  margin:10px 0;
}
.footer_social_links .navigation li{
  padding:0 0.3125rem;
}
.footer_social_links .navigation li a{
  width:2.125rem;
  height:2.125rem;
  display:flex;
  align-items:center;
  justify-content:center;
  border-radius:3.125rem;
  background-color:var(--theme-footer-background-color);
  font-size:1.3125rem;
  transition:0.5s;
  margin-top:0.3125rem;
}
.footer_social_links .navigation li a:hover{
  background-color:var(--theme-button-background-color-hover);
  color:var(--theme-button-font-color-hover);
  text-decoration:none;
}
.footer_social_links .navigation li a i{
  font-style:normal;
  font-family:"Font Awesome 5 Brands";
  line-height:normal;
}
.footer_social_links .navigation li a:hover i{
  color:var(--theme-button-font-color-hover) !important;
}
.pulse_footer .custom_footer_heading{
  font-size:1.125rem;
  font-weight:600 !important;
  color:var(--theme-footer-font-color);
  padding:0 0 0.625rem;
  margin-bottom:0;
  position:relative;
}
.footer_link_bottom{
  margin-top:0.9375rem;
}
.footer_link_bottom li{
  margin-top:15px;
}
.footer_link_bottom li a{
  font-weight:400;
  display:block;
  position:relative;
  transition:0.5s;
}
[dir="rtl"] .footer_link_bottom li a{
  padding-left:0;
  padding-inline-start:1.375rem;
}
.footer_link_bottom li a:hover{
  color:var(--theme-footer-link-color);
  text-decoration:none;
}
.layout_core_menu_footer a{
  color:var(--theme-footer-link-color);
}
.layout_page_footer *{
  color:var(--theme-footer-link-color);
}
.pulse_footer_bottom{
  padding:1.125rem 0;
  margin-top:0.9375rem;
}
.pulse_footer_bottom_inner{
  display:flex;
  align-items:center;
}
.pulse_footer_bottom_left{
  display:flex;
  align-items:center;
  justify-content:flex-start;
  font-size:var(--theme-font-size-small);
}
.pulse_footer_bottom_left .menu_core_footer{
  margin-left:1.875rem;
  text-decoration:none;
}
[dir="rtl"] .pulse_footer_bottom_left .menu_core_footer{
  margin-left:0;
  margin-right:1.875rem;
}
.core_footer_menu_item{
  position:relative;
}
.pulse_footer_bottom_left .core_footer_menu_item::after{
  content:'';
  position:absolute;
  width:5px;
  height:5px;
  border-radius:3.125rem;
  left:0.75rem;
  top:44%;
  background-color:var(--theme-footer-link-color);
}
[dir="rtl"] .pulse_footer_bottom_left .core_footer_menu_item::after{
  left:auto;
  right:0.75rem;
}
.pulse_footer_bottom_left .menu_core_footer:hover{
  color:var(--theme-footer-link-color);
}
.pulse_footer_bottom_left .menu_core_footer:hover::after{
  background-color:var(--theme-footer-link-color);
}
.pulse_footer_bottom .language_chooser .language_chooser_btn{
  color:var(--theme-footer-link-color);
  font-size:var(--theme-footer-link-color);
  padding:0;
  border:0;
}
.footer_donotsell{
  margin-top:0.625rem;
  font-weight:400;
  font-size:0.9rem;
  display:flex;
  align-items:center;
  font-size:var(--theme-font-size-small);
}
.footer_donotsell input{
  margin-top:0 !important;
}
.pulse_footer_bottom_right{
  flex:1;
  justify-content:flex-end;
  margin-left:0.9375rem;
  display:flex;
}
[dir="rtl"] .pulse_footer_bottom_right{
  margin-left:0;
  margin-right:0.9375rem;
}
#global_footer .language_chooser .dropdown-menu .dropdown-item span{
  color:var(--theme-font-color);
}
#global_footer .language_chooser .dropdown-menu{
  padding:8px 0px;
}
/*
GLOBAL NOTICES (OUTSIDE FORMS)
Used to show a message or notice with an icon on a page,
usually above content, not within a form.
*/
.tip{
  overflow:hidden;
  clear:both;
}
.tip > span{
  border-radius:0.3125rem;
  background-color:#f6a420;
  color:#fff;
  border-width:0.0625rem;
  display:flex;
  gap:10px;
  padding:0.625rem 0.9375rem;
  margin-bottom:20px;
}
.tip > span:before{
  content:"\f0eb";
  font-family:'Font Awesome 6 Free';
  margin-right:0.3125rem;
}
[dir="rtl"] .tip > span:before{
  margin-right:0;
  margin-left:0.3125rem;
}
.tip > span > a{
  color:#fff;
}
/*
GLOBAL FORM RESPONSES
Used to show feedback from form submissions, i.e.
error/result messages.
*/
ul.form-errors,
ul.form-notices{
  margin:0 0 1.25rem 0;
  overflow:hidden;
}
* + ul.form-errors,
* + ul.form-notices{
  margin-top:1.25rem;
}
ul.form-errors > li,
ul.form-notices > li{
  border-radius:0.3125rem;
  margin:0.4375rem 0.3125rem 0.4375rem 0.3125rem;
  padding:0.625rem 0.9375rem 0.625rem 0.9375rem;
  max-width:37.5rem;
  overflow:hidden;
  border:0.0625rem solid #ccc;
  color:#464646;
  box-sizing:border-box;
}
[dir="rtl"] ul.form-errors > li,
[dir="rtl"] ul.form-notices > li{
  float:right;
  clear:right;
}
ul.form-errors > li > b,
ul.form-notices > li > b{
  text-transform:uppercase;
  font-size:90%;
}
ul.form-errors > li > ul > li,
ul.form-notices > li > ul > li{
  font-size:90%;
}
ul.form-errors > li{
  background-color:#ff7d5f;
  color:#fff;
  border:none;
}
ul.form-errors > li:before{
  content:"\f071";
  font-family:'Font Awesome 6 Free';
  margin-right:0.3125rem;
  color:#fff;
  font-weight:900 !important;
  float:left;
}
[dir="rtl"] ul.form-errors > li:before{
  margin-right:0;
  margin-left:0.3125rem;
}
ul.form-notices > li{
  background-color:#6fad76;
  color:#fff;
  border:none;
}
ul.form-notices > li:before{
  content:"\f00c";
  font-family:'Font Awesome 6 Free';
  margin-right:0.3125rem;
  color:#fff;
  font-weight:900 !important;
}
[dir="rtl"] ul.form-notices > li:before{
  margin-right:0;
  margin-left:0.3125rem;
}
/*
GLOBAL FORM ELEMENTS
Used for most forms throughout the site.
*/
button{
  border-radius:0.625rem;
  padding:.5em .8em;
  font-size:100%;
  font-weight:600;
  border:none;
  transition:all .2s ease-in-out;
  outline:none !important;
  color:var(--theme-button-font-color);
  background-color:var(--theme-button-background-color);
}
button:hover,
button:focus-visible{
  color:var(--theme-button-font-color-hover);
  background-color:var(--theme-button-background-color-hover);
  border-color:var(--theme-button-border-color-hover);
  cursor:pointer;
  opacity:.8;
  transition:all .2s ease-in-out;
}
button:active{
  color:var(--theme-button-font-color-hover);
  background-color:var(--theme-button-background-color-hover);
  border-color:var(--theme-button-border-color-hover);
  background-image:none;
}
input[type=text],
input[type=email],
input[type=password],
input.text,
textarea,
.form-control,
html .selectize-input{
  background-color:var(--theme-input-background-color);
  color:var(--theme-input-font-color);
  border-width:0.125rem;
  border-color:var(--theme-input-border-color);
  padding:0.625rem 0.9375rem;
  resize:none;
  box-sizing:border-box;
  outline-width:0;
  border-radius:0.625rem;
  box-shadow:inherit !important;
  font-size:var(--theme-font-size);
}
.form-control:focus{
  background-color:var(--theme-input-background-color);
  color:var(--theme-input-font-color);
}
.global_form .selectize-input input{
  color:var(--theme-input-font-color);
  min-height:auto;
}
.global_form .selectize-input.items.has-options{
  display:flex;
  align-items:center;
  flex-wrap:wrap;
}
input:focus-visible,
select:focus-visible,
textarea:focus-visible,
select:focus-visible{
  outline:none;
}
input[type=checkbox],
input[type=radio]{
  border:none;
  padding:0;
  margin:0.25rem 0.3125rem 0 0;
  width:auto;
  display:block;
  float:left;
}
[dir="rtl"] input[type=checkbox],
[dir="rtl"] input[type=radio]{
  margin:0.25rem 0 0 0.3125rem;
  float:right;
}
input[type=checkbox] + label,
input[type=radio] + label{
  display:block;
  cursor:pointer;
}
textarea{
  width:100%;
  resize:none;
}
textarea.codebox{
  width:95%;
  min-height:12.5rem;
  font-family:courier new, courier, serif;
}
select{
  border-radius:0.625rem;
  background-color:var(--theme-input-background-color);
  color:var(--theme-input-font-color);
  border-width:0.125rem;
  border-color:var(--theme-input-border-color);
  padding:0.625rem 0.9375rem;
  padding-right:1.25rem;
  outline-width:0;
  border-radius:0.625rem;
  font-size:var(--theme-font-size);
}
[dir="rtl"] select{
  padding:0.625rem 0.9375rem;
  padding-right:1.25rem;
}
select option{
  padding:0 0.625rem 0 0.1875rem;
  font-family:Arial, Helvetica, sans-serif;
}
[dir="rtl"] select option{
  padding:0 0.1875rem 0 0.625rem;
}
a.buttonlink{
  display:inline-block;
  font-size:var(--theme-font-size);
}
a.buttonlink_right{
  font-weight:600 !important;
  display:inline-block;
}
a.buttonlink:hover
a.buttonlink_right:hover{
  text-decoration:none;
}
br.multi-text-separator{
  margin-bottom:0.5rem;
}
.selectize-control .selectize-dropdown{
  border-width:0;
}
/*IM text area */
textarea.im_menu_convo_input{
  padding:0 !important;
}
/*
LARGE BOX FORM
These styles are for large forms that are given an exclusive page.
They are not intended for smaller forms that are embedded elsewhere.
Examples:Signup form, member settings form, etc.
*/
/* form container */
.global_form_wrap{
  margin:0;
}
.global_form{
  clear:both;
}
/* external form border */
/* .global_form > div{
  margin:0 auto 0 auto;
  padding:5px;
} */
/* internal form border */
.global_form > div > div{
  padding:0;
  background-color:transparent;
  box-sizing:border-box;
}
.global_form > div > div h3{
  font-size:var(--theme-headline-size-medium);
  font-weight:600;
  margin:-0.9375rem -0.9375rem 0.9375rem;
  padding:1.25rem;
  border-radius:var(--theme-widget-radius) var(--theme-widget-radius) 0 0;
  color:var(--theme-headline-color);
  font-family:var(--theme-heading-font-family);
}
.global_form_wrap .global_form > div > div h3{
  background-color:var(--theme-list-background-color-alt);
}
.global_form > div > div h3 + .form-elements,
.global_form > div > div p + .form-elements{
  margin-top:20px;
}
.global_form_wrap .global_form > div .form-elements{
  overflow:hidden;
  padding:0 10px;
}
/* form headline */
.global_form div.form-wrapper-heading{
  font-weight:600 !important;
  margin-bottom:0.9375rem;
}
.global_form div.form-wrapper-heading > span{
  display:block;
  background:transparent;
}
/* form instructions (after title) */
.global_form > div > div > h3 + p{
  max-width:100%;
}
/* container row for a label (left) and element (right) */
.global_form div.form-wrapper{
  clear:both;
  display:flex;
  flex-wrap:wrap;
  gap:15px;
}
/* left-side element label container */
.global_form div.form-label{
  font-weight:var(--theme-font-weight-bold);
  color:var(--theme-font-color);
  padding-top:15px;
  margin:0;
  width:250px;
}
.global_form div.form-label label > i{
  margin-right:0.3125rem;
}
[dir="rtl"] .global_form div.form-label label > i{
  margin-left:0.3125rem;
  margin-right:0;
}
/* right-side form element container */
.global_form div.form-element{
  min-width:650px;
  max-width:40.625rem;
  text-align:left;
  margin-bottom:1.25rem;
}
[dir="rtl"] .global_form div.form-element{
  text-align:right;
  float:right;
}
/* all paragraphs of text in the form */
.global_form div > p{
  padding-bottom:0.625rem;
}
/* paragraphs of text that come after an input element */
.global_form .form-element input:not([type="radio"], [type="checkbox"]) + p,
.global_form .form-element select + p,
.global_form .form-element textarea + p,
.global_form .form-element .selectize-control + p{
  margin:0.3125rem 0 0;
  font-size:var(--theme-font-size-small);
  color:var(--theme-font-color-light);
}
/* all text inputs in form */
.global_form input[type=text],
.global_form input[type=email],
.global_form input[type=password],
.global_form .selectize-input,
.global_form select{
  width:100%;
}
.global_form .tox-tinymce{
  width:100% !important;
}
/* only for text inputs that come after other text inputs */
/* i.e. for when there is a vertical list of text inputs */
.global_form input[type=text] + input[type=text]{
  display:block;
  margin-top:0.3125rem;
}
/* all checkboxes and radios in form */
.global_form div.form-element .form-options-wrapper{
  width:100%;
}
.global_form input[type=checkbox],
.global_form input[type=radio]{
  clear:left;
}
[dir="rtl"] .global_form input[type=checkbox],
[dir="rtl"] .global_form input[type=radio]{
  clear:right;
}
/* for clickable labels that appear to the right of elements */
/* such as checkboxes or radios */
.global_form input + label{
  overflow:hidden;
  display:block;
  margin-top:0;
  margin-left:0.125rem;
}
[dir="rtl"] .global_form input + label{
  margin-left:0;
  margin-right:0.125rem;
}
/* all textareas in form */
.global_form textarea{
  max-width:100%;
  min-height:7.5rem;
}
.global_form p.description{
  padding:0;
  margin:0 0 10px;
}
.global_form #submit-element{
  margin-bottom:0;
}
.global_form button[type=submit]{
  padding:0.625rem 0.9375rem;
  margin-right:0.1875rem;
  min-width:180px;
  min-height:45px;
}
[dir="rtl"] .global_form button[type=submit]{
  margin-right:0;
  margin-left:0.1875rem;
}
.global_form_popup button[type=submit]{
  padding:0.625rem 0.9375rem;
  margin-right:0.1875rem;
  min-width:inherit;
  min-height:inherit;
}
.intopenai_form_element .form-label{
  display:block;
}
/* Required field asterisk */
.form-label .required::after,
label.required::after{
  content:' *';
  color:#f00;
}
#global_page_user-signup-index .form-label .required::after,
#global_page_user-signup-index label.required::after{
  position:absolute
}
/*
SMALL BOX FORM
These styles are for small box forms, such
as the login box found by default on the main
index page. Form names and inputs are stacked
vertically (not floated) to fit into small-width
content areas.
*/
.global_form_box{
  background-color:var(--theme-pulldown-background-color);
  border:0 solid var(--theme-pulldown-border-color);
  border-radius:0.3125rem;
  width:auto;
}
.global_form_box > div > ul > li + li,
.global_form_box .form-wrapper + .form-wrapper{
  margin-top:0.625rem;
}
.global_form_box .form-label{
  padding:0;
  width:auto;
  float:none;
  clear:both;
  margin:0;
}
.global_form_box label{
  text-align:left;
  display:block;
  margin-bottom:0.125rem;
  font-weight:var(--theme-font-weight-bold);
  color:var(--theme-font-color);
}
[dir="rtl"] .global_form_box label{
  text-align:right;
}
.global_form_box .form-element{
  overflow:hidden;
}
/*
FILTER FORM
These styles are for small, transparent forms
that contain search boxes or filter fields. They
are usually found on browse pages.
*/
form.filters{
  background-color:var(--theme-pulldown-background-color);
  border-width:0;
  border-radius:0.3125rem;
}
form.filters div.form-label{
  margin-bottom:0.1875rem;
}
form.filters div.form-element{
  margin-top:0.125rem;
  margin-bottom:0.625rem;
}
form.filters button{
  margin-top:0.25rem;
}
form.filters dt{
  font-size:90%;
  padding-bottom:0.125rem;
}
form.filters dd{
  margin-bottom:0.5rem;
}
/*
POPUP FORM
These are used to style popup (i.e. smoothbox) forms.
Also used to style popup response messages, etc.
*/
#smoothbox_window body{
  background-color:var(--theme-list-background-color);
}
.global_form_popup{
  padding:0.625rem 0.625rem 0.625rem 0.8125rem;
  overflow:hidden;
}
[dir="rtl"] .global_form_popup{
  padding:0.625rem 0.8125rem 0.625rem 0.625rem;
  float:right;
}
.global_form_popup #submit-wrapper,
.global_form_popup #cancel-wrapper{
  float:left;
  overflow:hidden;
}
[dir="rtl"] .global_form_popup #submit-wrapper,
[dir="rtl"] .global_form_popup #cancel-wrapper{
  float:right;
}
.global_form_popup #buttons-wrapper{
  margin-top:0.625rem;
}
[dir="rtl"] .global_form_popup #buttons-wrapper button{
  margin-right:0;
  margin-left:0.25rem;
}
.global_form_popup_message{
  display:block;
  padding:1em;
  text-align:center;
  font-weight:600 !important;
}
/*
UPLOAD FORM
Styles the file upload form.
*/
#form-upload #submit-wrapper{
  display:none;
}
#form-upload #demo-status a.buttonlink{
  margin-right:0.9375rem;
}

/*
HEADLINE
Used at the top of most browse pages. Often contains button-style tabs.
*/
.generic_layout_container .headline{
  display:flex;
  align-items:center;
  gap:5px;
}
.headline h2{
  margin:0;
  margin-inline-end:1.25rem;
  vertical-align:middle;
  font-size:1.2rem;
  font-weight:600;
  padding-block:0.3125rem;
  /* display:none !important; */
}
/* #global_page_user-index-browse .headline h2{
  display:block !important;
} */
.headline .tabs{
  border:0;
  flex:1;
}
.tabs{
  display:inline-block;
  vertical-align:middle;
  margin-left:0;
  border-bottom:1px solid var(--theme-border-color);
}
[dir="rtl"] .tabs{
  margin-left:0;
}
.tabs > ul{
  display:flex;
  flex-wrap:wrap;
  gap:0.625rem;
  vertical-align:middle;
}
.tabs > ul > li > a{
  display:inline-block;
  color:var(--theme-tabs-font-color);
  font-size:var(--theme-tabs-font-size);
  font-family:var(--theme-buttontabs-font-family);
  font-weight:500;
  padding:10px;
  transition:all 0.6s ease;
}
.tabs > ul > li.active > a{
  color:var(--theme-color);
  font-weight:600;
}
.tabs > ul > li > a:focus-visible{
  border-width:0;
  outline:none;
  background-color:var(--theme-list-background-color-alt) !important;
}
.tabs > ul > li.active > a:hover{
  text-decoration:none;
}

/*
TABS (TAB STYLE, NON-DEFAULT)
*/
.tabs_alt{
  background-color:transparent;
  background-image:none;
  padding:0;
  -moz-user-select:none;
  -webkit-user-select:none;
}
.tabs_alt > ul{
  display:flex;
  flex-wrap:wrap;
  gap:0.3125rem 0.625rem;
  align-items:center;
  justify-content:flex-start;
  margin:0 0 var(--theme-widget-spacing);
  border-radius:var(--theme-widget-radius);
  border-radius:15px;
  padding:0px 1.25rem;
  background:var(--theme-list-background-color);
  border:var(--theme-border-width) solid var(--theme-border-color);
  box-shadow:var(--theme-layout-box-shadow);
}
.dark_mode .tabs_alt > ul{
  box-shadow:none;
}
.tabs_alt > ul > li + li{
  margin-left:0.25rem;
}
[dir="rtl"] .tabs_alt > ul > li + li{
  margin-left:0;
  margin-right:0.25rem;
}
.tabs_alt > ul > li > a:focus-visible{
  color:var(--theme-tabs-font-color-active);
  background-color:var(--theme-tabs-background-color-active);
}
.tabs_alt > ul > li > a{
  text-decoration:none;
  color:var(--theme-tabs-font-color);
  outline:none;
  padding:0.9375rem 0px !important;
  display:block;
  font-weight:500;
  margin-bottom:-0.0625rem;
  border-radius:0;
  font-family:var(--theme-tabs-font-family);
  font-size:var(--theme-tabs-font-size);
  border-bottom:2px solid transparent !important;
  transition:all 0.5s ease;
}
.tabs_alt > ul > li.tab_active > a, 
.tabs_alt > ul > li.active > a{
  position:relative;
  color:var(--theme-color) !important;
  font-weight:500;
  background:transparent !important;
  border-bottom:2px solid var(--theme-tabs-border-color-active) !important;
  border-radius:0 !important;
  transition:all 0.5s ease;
}
.tabs_alt > ul > li > a:focus-visible{
  color:var(--theme-font-color) !important;
  background:transparent !important;
  border-bottom:2px solid var(--theme-tabs-border-color-active) !important;
  border-radius:0 !important;
}
.tabs_alt > ul > li.tab_open > a{
  color:var(--theme-font-color) !important;
  background:transparent !important;
  border-radius:0;
}
.tabs_alt > ul > li.tab_open > a:focus-visible{
  color:var(--theme-font-color) !important;
  background:transparent !important;
  font-weight:700 !important;
  border-bottom:4px solid var(--theme-tabs-border-color-active) !important;
  border-radius:0 !important;
}
.tabs_alt > ul > li.tab_active > a > span, 
.tabs_alt > ul > li.active > a > span, 
.tabs_alt > ul > li > a:hover span{
  color:var(--theme-color) !important;
  font-weight:600;
  transition:all 0.5s ease;
}
.tabs_alt > ul > li > a span{
  font-size:90%;
  font-weight:normal;
  margin-left:0.25rem;
  border:none;
  font-weight:500;
}
[dir="rtl"] .tabs_alt > ul > li > a span{
  margin-left:0;
  margin-right:0.25rem;
}
.tab_container_inactive{
  display:none;
}
.tab_pulldown_contents_wrapper{
  border-radius:0.3125rem;
  overflow:hidden;
  margin-top:0 !important;
  display:none;
  margin-top:0.625rem;
  position:absolute;
}
.tab_pulldown_contents{
  border-width:0.0625rem;
  border-radius:0.3125rem;
  overflow:hidden;
  background:var(--theme-pulldown-contents-background-color);
  z-index:1;
}
.tab_pulldown_contents > ul{
  min-width:9.375rem;
}
.tab_pulldown_contents > ul > li{
  font-family:var(--theme-buttontabs-font-family);
}
.tab_pulldown_contents > ul > li a{
  display:block;
  padding:0.625rem;
  font-family:var(--theme-tabs-font-family);
  font-size:var(--theme-tabs-font-size);
  color:var(--theme-tabs-font-color);
  font-weight:500;
}
.tab_pulldown_contents > ul > li.active a{
  color:var(--theme-color);
  font-weight:600;
}
.tab_pulldown_contents > ul > li + li a{
  border-top:0.0625rem solid var(--theme-border-color);
}
.tab_pulldown_contents > ul > li:hover a{
  color:var(--theme-color);
  text-decoration:none;
}
.tab_pulldown_contents > ul > li a:focus-visible{
  color:var(--theme-color);
  outline:none;
}
.tabs_alt > ul > li.tab_open .tab_pulldown_contents_wrapper{
  display:block;
  z-index:11;
}
[dir="rtl"] .tabs_alt > ul > li.tab_open .tab_pulldown_contents_wrapper{
  /* left:0; */
}
/*
TAGS
Styles lists of tags that are used for message recipients, lists of friend
lists, etc. Each tag has its own remove link.
*/
.tag{
  border-radius:0.3125rem;
  display:inline-block;
  background-color:var(--theme-tag-background-color);
  font-weight:600 !important;
  display:inline-block;
  float:left;
  padding:0.3125rem 0.5rem;
  margin:0 0.625rem 0.3125rem 0rem;
  font-size:90%;
}
[dir="rtl"] .tag{
  float:right;
  margin:0rem 0 0.3125rem 0.625rem;
}
.tag > a{
  text-decoration:none;
  padding-left:0.375rem;
  text-transform:uppercase;
}
[dir="rtl"] .tag > a{
  float:left;
  padding-left:0;
  padding-right:0.375rem;
}
/* User Sidebar Profile  */
.user_sidebar_photo_cover{
  height:6.25rem;
}
.user_sidebar_photo_main .profile_photo{
  margin-top:-50px;
  height:80px;
  width:80px;
}
.user_sidebar_photo_content{
  padding-bottom:20px;
}
.user_sidebar_photo_main{
  flex-direction:column;
  justify-content:center;
  align-items:center;
}
.user_sidebar_photo_main .user_sidebar_photo_info .user_name{
  font-size:var(--theme-headline-size-medium);
  font-weight:500;
}
.user_sidebar_photo_main .user_sidebar_photo_info .username{
  font-size:var(--theme-font-size-small);
  font-weight:500;
  text-align:center;
}
/*Member Home Page*/
.layout_user_home_links .home-links-user{
  display:none;
}
.quicklinks{
  overflow:visible;
  margin:0 -0.9375rem;
}
.quicklinks ul{
  margin-bottom:0;
}
.quicklinks ul li{
  position:relative;
  padding:0;
  margin:0;
  border:0;
}
.quicklinks ul li .buttonlink{
  font-size:var(--theme-font-size);
  font-weight:400;
  color:var(--theme-font-color);
  padding:0.3125rem 0 0.3125rem 48px;
  display:block;
  padding-block:0.5rem;
}
[dir="rtl"] .quicklinks ul li .buttonlink{
  padding:0.3125rem 2.8125rem 0.3125rem 0rem;
}
.quicklinks ul li a:before{
  color:var(--theme-font-color-light);
  position:absolute;
  left:0.9375rem;
  text-align:center !important;
  width:1.5rem;
  font-size:16px;
  font-family:inherit;
  font-weight:inherit;
}
[dir="rtl"] .quicklinks ul li a:before{
  left:auto;
  right:0.9375rem;
}
.quicklinks ul li .buttonlink:hover,
.quicklinks ul li.active .buttonlink{
  color:var(--theme-font-color);
  background-color:var(--theme-list-background-color-hover);
}
.sidebar_links a{
  border-radius:0.625rem;
  padding:0 .625rem !important;
  line-height:2.5rem;
  min-height:45px;
  font-weight:600;
}
/*User Profile Page*/
.user_cover_info_stats{
  flex-wrap:wrap;
}
/* User Cover Image */
@media (max-width:767px){
  #global_page_user-profile-index #global_wrapper{
    padding-top:0;
  }
  .user_cover_content{
    align-items:center !important;
  }
  .user_cover_image{
    border-radius:0 !important;
  }
  .user_cover_fade, 
  .user_cover_overlay{
    border-radius:0 !important;
  }
  .user_cover_main_photo{
    padding:3px !important;
    margin-top:-65px !important;
  }
  .user_cover_main_photo .user_cover_change_cover_main .dropdown > button{
    height:30px !important;
    width:30px !important;
  }
  .user_cover_change_cover{
    right:15px !important;
    bottom:15px !important;
    top:auto !important;
  }
  .user_cover_change_cover .dropdown>button{
    height:30px !important;
    width:30px !important;
  }
  .user_cover_info_left{
    text-align:center;
  }
  .user_cover_info{
    flex-direction:column;
    justify-content:center;
    align-items:center;
    text-align:center !important;
  }
  .user_cover_info_stats{
    justify-content:center;
  }
  #status_edit_link{
    display:flex;
    justify-content:center;
    margin-top:0.3125rem;
  }
  .user_cover_buttons{
    margin-top:15px;
  }
  .user_cover_buttons>ul{
    justify-content:center;
  }
}
.user_profile_info > ul > li{
  border:0;
  padding:10px 15px;
}
.user_profile_info li svg{
  color:var(--theme-font-color) !important;
}
.layout_user_list_online div{
  padding:0;
}
.layout_user_list_online .whosonline_thumb{
  margin:0 0.125rem 0.25rem;
}
.layout_user_list_online .whosonline_thumb .bg_thumb_icon{
  height:3.25rem;
  width:3.25rem;
  position:relative;
}
.layout_user_list_online .whosonline_thumb .bg_thumb_icon::after{
  content:'';
  position:absolute;
  background-color:#00ba00;
  width:0.625rem;
  height:0.625rem;
  border-radius:3.125rem;
  bottom:0.3125rem;
  right:0.0625rem;
}
[dir="rtl"] .layout_user_list_online .whosonline_thumb .bg_thumb_icon::after{
  right:auto;
  left:0.0625rem;
}
.layout_core_statistics ul{
  padding:0;
  margin:0 -0.9375rem;
}
.layout_core_statistics ul > li{
  padding:0.375rem 0.9375rem;
  display:flex;
  align-items:center;
  justify-content:flex-start;
  overflow:hidden;
}
.layout_core_statistics ul > li:nth-child(odd){
  background-color:var(--theme-list-background-color-alt);
}
.layout_core_statistics ul > li div{
  text-transform:capitalize;
  white-space:nowrap;
  overflow:hidden;
  display:inline-block;
  vertical-align:middle;
  float:none;
  text-overflow:ellipsis;
  flex:1;
  font-size:1em;
}
.layout_core_statistics ul > li span{
  float:right;
  margin:0 0 0 0.3125rem;
  font-size:1em;
  float:none;
  order:1;
}
[dir="rtl"] .layout_core_statistics ul > li span{
  float:none;
  margin-left:0;
  margin-right:0.3125rem;
}
[dir="rtl"] .layout_core_statistics ul > li div{
  float:none;
}

/*Login Page*/
#global_page_user-auth-forgot #global_content{
  min-height:auto !important;
}
/* #global_page_user-auth-forgot #global_wrapper,
#global_page_user-auth-login #global_wrapper{
  padding:30px 0px 20px 0px;
} */
.layout_page_user_auth_login{
  margin:auto;
  border-radius:var(--theme-widget-radius);
  overflow:hidden;
}
.layout_page_user_auth_login .layout_core_content{
  overflow:hidden;
  max-width:600px !important; 
  margin:30px auto !important;
  padding:40px !important;
}
.user_login_page form > div{
  padding:0 !important;
  background:transparent !important;
}
.user_login_bg{
  display:none;
}
.user_login_page .user_login_form form{
  background:transparent;
}
#user_form_login > div > div > .form-elements{
  display:flex;
  flex-direction:column;
  position:relative;
}
.user_login_page .user_login_form div.form-wrapper{
  display:block;
}
.user_login_page .user_login_form div.form-wrapper .user_showhidepassword,
.required_login_form .global_form .user_showhidepassword{
  position:absolute;
  right:0;
}
[dir="rtl"] .user_login_page .user_login_form div.form-wrapper .user_showhidepassword,
[dir="rtl"] .required_login_form .global_form .user_showhidepassword{
  position:absolute;
  left:0;
  right:auto;
}
.user_login_page #user_form_login .user_showhidepassword > i{
  margin-top:-38px;
}
.required_login_form .global_form .user_showhidepassword > i{
  margin-top:-48px;
}

#user_form_login #forgot-element{
  margin-block:0px !important;
}
#user_form_login #forgot-element > span{
  text-align:end;
}
#user_form_login #submit-wrapper{
  order:4;
  margin-bottom:20px !important;
  margin-top:10px;
}
#user_form_login #forgot-wrapper{
  margin-top:0;
}
#user_form_login #sociallinks-wrapper{
  order:5;
}
.user_login_page .user_login_form .form-elements > #password_buttons-wrapper{
  margin-bottom:5px !important;
}
/* .user_login_page .user_login_form .form-elements > #password_buttons-wrapper #password-wrapper{
  margin-bottom:0px !important;
} */
.user_login_page .user_login_form #fieldset-password_buttons .form-wrapper{
  margin-bottom:5px;
}
/*Recent Login Popup*/
.user_login_form .recent_login{
  border:0;
}
.user_password_popup_btn{
  margin-bottom:15px !important;
}

@media (max-width:767px){
  .layout_page_user_auth_login .layout_core_content{
    margin:0 0 20px !important;
    padding:30px 20px !important;
  }
  .user_login_page .signup_link{
    padding-top:20px;
  }
  .user_login_page #user_form_login #sociallinks-wrapper{
    margin:20px 0 0 0;
  }
  #global_page_user-auth-forgot #global_content{
    padding:0;
  }
  .authpage #global_content .layout_core_content{
    margin:0 auto 20px !important;
    padding:30px 20px !important;
    border:0 !important;
    border-radius:0;
    box-shadow:none;
  }
  .user_login_page form > div{
    background:transparent;
  }
}

/*Sign Up Page*/
[dir="rtl"] .user_login_page .user_login_form input[type="password"],
[dir="rtl"] #global_page_core-error-requireuser input[type="password"],
[dir="rtl"] #global_page_user-signup-index input[type="password"],
[dir="rtl"] #global_page_user-settings-password input[type="password"]{
  padding-right:0.5rem;
}
/*Stories */
.layout_stories_all_stories{
  background:none !important;
  border-width:0 !important;
  box-shadow:none !important;
  padding:0 !important;
}
.layout_stories_all_stories h3{
  border-width:0;
  font-size:0;
  padding:0;
  margin:0 0 10px !important;
  display:flex;
  justify-content:space-between;
}
.layout_stories_all_stories h3 a{
  float:none !important;
}
.stories_allstories_item{
  background-color:var(--theme-list-background-color);
}
.stories_allstories_item_owner_cont,
.stories_allstories_item_name{
  font-size:var(--theme-font-size-small);
}
/*Hastag Page*/
.layout_core_show_search_hashtags h3{
  padding:0 !important;
  border:0;
  margin:0;
  background-color:transparent;
  border-radius:0;
}

/* Status Post Box  */
.activity_composer_active .activity_post_container{
  border-radius:var(--theme-dropdown-radius) !important;
  box-shadow:none;
}
.activity_post_box{
  padding:20px var(--theme-item-spacing);
}
.activity_post_media_options{
  padding:15px 0;
}
.activity_post_media_options_icon > a{
  padding:0 12px;
}
[dir="rtl"] .compose-content-counter{
  text-align:center !important;
}
/* Activity Feed Filters Tabs  */
/* .activity_feed li > .block{
  background-color:var(--theme-list-background-color) !important;
} */
.activity_feed_filters{
  padding:0 0.9375rem;
  box-shadow:var(--theme-layout-box-shadow);
  border-radius:var(--theme-widget-radius);
}
.activity_feed_filters > ul{
  gap:20px;
  justify-content:flex-end;
}
.activity_feed_filters > ul > li.activity_filter_img{
  border-radius:var(--theme-widget-radius);
}
.activity_feed_filters > ul > li{
  flex-grow:inherit;
}
.activity_feed_filters > ul > li > a{
  padding-block:0.9375rem;
  padding-inline:0;
  border-radius:0;
  border-bottom:2px solid transparent !important;
}
.activity_feed_filters > ul > li.active > a{
  background:transparent !important;
  color:var(--theme-color) !important;
  border-bottom:2px solid var(--theme-tabs-border-color-active) !important;
  border-radius:0 !important;
}
/*Activity Feed*/
.layout_activity_feed > h3{
  margin:0 0 0.9375rem !important;
  padding:0 !important;
}
ul.feed > li{
  margin:0 0 var(--theme-widget-spacing);
}
.activity_feed_item_bodytext > span{
  line-height:175%;
}
ul.feed .feed_item_icon > ul{
  display:flex;
  justify-content:space-between;
}
ul.feed .feed_item_icon > ul > li{
  flex:1;
}
ul.feed .feed_item_icon > ul > li > a{
  display:flex;
  justify-content:center;
  padding:10px;
  border-radius:5px;
  color:var(--theme-font-color-light);
}
ul.feed .feed_item_icon > ul > li > a:hover{
  background-color:var(--theme-secondary-button-background-color);
  color:var(--theme-secondary-button-font-color);
}
ul.feed .feed_item_icon > ul > li > a span{
  font-weight:400;
}
.comment_comments > form{
  padding:20px 0px !important;
}
.comment_comments > ul > li{
  padding-top:5px;
}
.activity_feed_options_btn{
  transform:rotate(90deg);
  background:transparent;
  border:0;
}
.activity_feed_options_btn:hover{
  background:transparent;
  border:0;
}
ul.feed .feed_item_attachments > .feed_attachment_album_photo > div > a img, 
ul.feed .feed_item_attachments > .feed_attachment_storage_file > div > a img{
  border-radius:0.625rem;
}
@media(min-width:768px){
  /*Photo View Start*/
  #global_page_activity-index-attachmentview #global_content{
    min-height:initial;
  }
  #global_page_activity-index-attachmentview #global_wrapper .photo_view_media_container,
  #global_page_activity-index-attachmentview #global_wrapper .layout_right{
    min-height:calc(100vh - 3.8125rem);
    max-height:calc(100vh - 3.8125rem);
  }
}
@media (max-width:767px){
  ul.feed > li > .block{
    box-shadow:none;
    border-radius:0 !important;
  }
  .activity_post_container{
    /* margin-inline:10px; */
  }
  .layout_activity_feed > h3{
    padding-inline:10px !important;
  }
  .feed .feed_item_attachments > span > div > a img{
    border-radius:0 !important;
    width:100%;
  }
  [class*=feed_images_]>[class*=feed_attachment_]{
    padding:1px;
  }
  html ul.feed .activity_feed_usercover ._cover{
    border-radius:0;
  }
  #global_page_user-profile-index ul.feed > li{
    width:auto;
  }
  #global_page_user-profile-index #global_content .layout_main .layout_middle{
    overflow:inherit;
  }
}
/* Profile User Info */
.layout_user_profile_fields .profile_fields{
  margin-bottom:10px;
}
.layout_user_profile_fields .profile_fields > ul > li + li{
  margin-top:10px;
}
.layout_middle .generic_layout_container.layout_user_profile_fields .profile_fields{
  margin-top:0;
}
.layout_middle .generic_layout_container.layout_user_profile_fields .profile_fields > h4{
  padding:12px 10px;
  font-weight:700;
  border-radius:8px;
  border:0;
  color:var(--pulse-headline-color);
  background-color:var(--theme-list-background-color-alt);
}
.user_cover_info_left{
  padding-right:5px;
}
/*Notification Page CSS*/
.notifications_layout_head{
  padding:0.625rem 0.9375rem;
}
.notifications_layout_inner ul.notifications > li{
  padding:0.625rem 0.9375rem;
}
html .categories_sidebar_listing li a.catlabel:before{
  color:var(--theme-font-color-light);
}
/*Banner*/
.layout_top .layout_middle > .layout_core_banner:nth-child(1){
  margin-top:-20px;
}
.layout_top .layout_core_banner{
  height:300px;
}
.layout_top .layout_core_banner > div{
  height:300px;
  border-radius:0;
  position:absolute;
  left:0;
  right:0;
}
.layout_top .layout_core_banner > div>section{
  padding-bottom:100px;
}
html .layout_top .layout_core_banner a:link,
html .layout_top .layout_core_banner a:visited{
  background-color:#fff;
  color:#111;
  display:inline-flex;
  margin-top:1rem;
  position:initial;
  gap:5px;
  padding:9px 20px;
}
.layout_top .layout_core_banner + .generic_layout_container{
  margin-top:-60px;
  position:relative;
}

/*User Dashboard*/
.user_setting_cover{
  background:var(--theme-list-background-color);
}
/* .user_setting_main_page_main{
  gap:1.875rem !important;
} */
.user_setting_global_form .global_form div{
  background:transparent;
}
.user_setting_global_form .global_form div.form-wrapper{
  gap:0;
}
@media (min-width:1024px){
  .user_setting_global_form.user_edit_form  .global_form .form-elements{
    width:100% !important;
  }
  .user_setting_global_form.user_edit_form  .global_form div.form-wrapper{
    gap:15px;
    display:inline-flex;
  }
  .user_setting_global_form.user_edit_form div.form-label{
    width:250px;
  }
  .user_setting_global_form.user_edit_form .global_form div.form-element{
    min-width:500px !important;
    max-width:500px !important;
  }
  #global_page_user-settings-password #resetalldevice-wrapper #resetalldevice-label{
    display:block;
  }
}
/*Create & Edit Forms*/
#global_page_album-index-upload .layout_core_content,
#global_page_album-album-edit .layout_core_content,
#global_page_blog-index-create .layout_core_content,
#global_page_blog-index-edit .layout_core_content,
#global_page_classified-index-create .layout_core_content,
#global_page_classified-index-edit .layout_core_content,
#global_page_classified-photo-upload .layout_core_content,
#global_page_music-index-create .layout_core_content,
#global_page_music-playlist-edit .layout_core_content,
#global_page_group-index-create .layout_core_content,
#global_page_group-group-edit .layout_core_content,
#global_page_group-photo-upload .layout_core_content,
#global_page_group-topic-create .layout_core_content,
#global_page_group-post-edit .layout_core_content,
#global_page_poll-index-create .layout_core_content,
#global_page_poll-poll-edit .layout_core_content,
#global_page_forum-forum-topic-create .layout_core_content,
#global_page_forum-post-edit .layout_core_content,
#global_page_event-index-create .layout_core_content,
#global_page_event-event-edit .layout_core_content,
#global_page_event-photo-upload .layout_core_content,
#global_page_event-topic-create .layout_core_content,
#global_page_event-post-edit .layout_core_content,
#global_page_travel-index-create .layout_core_content,
#global_page_travel-index-edit .layout_core_content,
#global_page_travel-photo-upload .layout_core_content,
#global_page_employment-index-create .layout_core_content,
#global_page_employment-index-edit .layout_core_content,
#global_page_bizlist-index-create .layout_core_content,
#global_page_bizlist-index-edit .layout_core_content,
#global_page_bizlist-photo-upload .layout_core_content,
#global_page_video-index-create .layout_core_content,
#global_page_video-index-edit .layout_core_content{
  max-width:980px;
  margin:0 auto 0.9375rem !important;
}