/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/

/*Mobile Tab Menu Start*/
.pulse_mobile_menu{
	background-color:var(--theme-list-background-color);
	position:fixed;
	bottom:0;
	left:0;
	width:100%;
	z-index:10;
	border-top-width:1px;
	box-shadow:0 0 5px rgba(0, 0, 0, 0.1);
  height:60px;
	display:none;
}

.pulse_mobile_menu_inner > ul{
	display:flex;
	justify-content:space-between;
	align-items:center;
	padding:0.5rem 0;
}
.pulse_mobile_menu_inner > ul > li{
	flex:1;
	display:flex;
	justify-content:center;
}
.pulse_mobile_menu_inner > ul > li > a{
	padding:0.625rem;
	position:relative;
}
.pulse_mobile_menu_inner > ul > li > a .counts{
  color:#fff !important;
  font-weight:400;
  margin:2px 0 0 12px;
  font-size:11px;
  padding:5px;
  min-width:20px;
  top:0;
}
[dir="rtl"] .pulse_mobile_menu_inner > ul > li > a .counts{
	margin:2px 12px 0 0;
}
.pulse_mobile_menu_inner > ul > li > a i{
	height:24px;
	width:24px;
	display:flex;
}
.pulse_mobile_menu_inner > ul > li > a i svg{
	fill:var(--theme-font-color) !important;
	height:100%;
	width:100%;
}
.pulse_mobile_menu_inner > ul > li.active > a i svg{
	fill:var(--theme-color) !important;
}
.pulse_mobile_menu_inner > ul > li > a i._profile_icon{
	border-radius:50%;
	overflow:hidden;
}
.pulse_mobile_menu_inner > ul > li > a i._profile_icon span{
	width:100%;
	height:100%;
	background-size:cover;
}
.pulse_mobile_menu_open,
.pulse_mobile_menu_open body{
	overflow:hidden;
}
.pulse_mobile_menu_content{
	background-color:var(--theme-list-background-color);
	display:none;
	position:fixed;
	bottom:60px;
	left:0;
	width:100%;
	z-index:1000;
	border-bottom-width:1px;
	height:calc(100dvh - 60px);
	flex-direction:column;
}
.pulse_mobile_profile_menu_guest{
  bottom:0;
  height:100%;
}
.pulse_mobile_menu_content.open{
  display:flex;
}
.pulse_mobile_menu_content_profile_guest{
  height:auto;
  border-top-width:1px;
  box-shadow:0 0 5px rgba(0, 0, 0, .1);
}
.pulse_mobile_menu_content_header{
	display:flex;
  align-items:center;
	justify-content:space-between;
	padding:15px;
}
.pulse_mobile_menu_content_header h2{
	color:var(--theme-font-color);
	font-size:22px;
	font-weight:600;
	padding:0;
	margin:0;
}
.pulse_mobile_menu_content_header a{
  background-color:var(--theme-list-background-color-alt);
  border-radius:50%;
  color:var(--theme-font-color);
  font-size:1rem;
  height:30px;
  width:30px;
  display:flex;
  align-items:center;
  justify-content:center;
}
.pulse_mobile_menu_content_inner{
	padding:15px;
	overflow:auto;
	flex:1;
}
/*Create Menu*/
.pulse_mobile_create_menu{
  padding:0;
  margin:0 -10px;
}
.pulse_mobile_create_menu_item a{
  display:flex;
  justify-content:flex-start;
  align-items:center;
  gap:10px;
  padding:10px;
}
.pulse_mobile_create_menu_item:hover{
  border-radius:var(--theme-item-radius);
  background-color:var(--theme-list-background-color-hover);
}
.pulse_mobile_create_menu_item_icon{
  background-color:var(--theme-secondary-button-background-color);
  color:var(--theme-secondary-button-font-color);
  height:40px;
  width:40px;
  display:flex;
  justify-content:center;
  align-items:center;
  border-radius:50%;
}
.pulse_mobile_create_menu_item_title{
  font-size:var(--theme-font-size);
  font-weight:500;
  margin:0;
  color:var(--theme-font-color) !important;
}
/*Profile Menu*/
.pulse_mobile_menu_profile .core_switch_account_pulldown{
  padding:15px;
}
.pulse_mobile_menu_btns .btn span{
	color:inherit;
}
.pulse_mobile_menu_btns ._login{
	border-color:var(--theme-button-border-color);
	background-color:var(--theme-button-background-color);
  color:var(--theme-button-font-color);
}
.pulse_mobile_menu_btns ._signup{
	border-color:var(--theme-color);
	background-color:var(--theme-list-background-color);
  color:var(--theme-color);
}
.pulse_mobile_menu_profile_user_switcher > a{
  border-radius:50%;
}
.pulse_mobile_menu_profile_user_switcher > a i{
  line-height:1;
}

.pulse_mobile_menu_profile_section ._head{
  font-weight:var(--theme-font-weight-bold);
  margin-bottom:5px;
}
.pulse_mobile_menu_profile_section > ul{
  border-width:1px;
  border-radius:10px;
	display:flex;
	flex-direction:column;
	flex:1;
  padding:5px 0;
}
.pulse_mobile_menu_profile_link_item_inner{
  display:flex;
  align-items:center;
  gap:.9375rem;
  padding:12px;
}
.pulse_mobile_menu_profile_link_item ._icon{
  height:30px;
  width:30px;
  aspect-ratio:1;
  display:flex;
  justify-content:center;
  align-items:center;
}
.pulse_mobile_menu_profile_link_item ._icon img{
  height:100%;
}
.pulse_mobile_menu_profile_link_item ._icon i{
  border-radius:50%;
  background-color:var(--theme-list-background-color-alt);
  height:100%;
  width:100%;
  font-size:16px;
  display:flex;
  align-items:center;
  justify-content:center;
}
.pulse_mobile_menu_profile_link_item ._info{
  flex:1;
}
.pulse_mobile_menu_profile_link_item ._right p{
  align-items:center;
}
.pulse_mobile_menu_profile_link_item ._right i{
  background-size:contain;
  height:20px;
  width:20px;
  line-height:1;
  display:flex;
  align-items:center;
  justify-content:center;
}
.pulse_mobile_menu_profile_link_item ._right i._coin{
  background-image:url(~/application/modules/Pulse/externals/images/menu-icons/coin.png);
}
[dir="rtl"] .pulse_mobile_menu_profile_link_item ._right i._arrow{
  position:relative;
  transform:rotate(180deg);
}
.pulse_mobile_menu_profile_link_more{
  padding:10px;
}
.pulse_mobile_menu_profile_link_more .btn{
  gap:5px;
  width:100%;
}

/*Accessibility Toggle*/
.pulse_mobile_menu_profile_link_item#thememodetoggle input[type="checkbox"]{
  position:absolute;
  opacity:0;
  visibility:hidden;
}
.pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle{
  background-color:var(--theme-list-background-color-hover);
  border-width:0.0625rem;
  border-radius:1.25rem;
  height:1.875rem;
  width:3.75rem;
  position:relative;
  display:flex;
  align-items:center;
  justify-content:space-between;
  padding:0 0.0625rem;
}
.pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before{
  content:"";
  background-color:var(--theme-button-background-color);
  border-radius:50%;
  height:1.5rem;
  width:1.5rem;
  position:absolute;
  left:0.125rem;
  top:0.125rem;
}
[dir="rtl"] .pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before{
  left:auto;
  right:0.125rem;
}
.pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle i{
  width:1.625rem;
  height:1.625rem;
  display:flex;
  align-items:center;
  justify-content:center;
  position:relative;
  z-index:1;
}
.pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle._light > i:nth-child(1),
.pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle._dark > i:nth-last-child(1){
  color:var(--theme-button-font-color) !important;
}
.dark_mode .pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before,
.light_mode .pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before{
  right:0.125rem;
  left:auto;
}
[dir="rtl"].dark_mode .pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before,
[dir="rtl"].light_mode .pulse_mobile_menu_profile_link_item#thememodetoggle .contrastmode_toggle:before{
  left:0.125rem;
  right:auto;
}

.pulse_mobile_menu_profile_link_item .resizer{
  display:flex;
}
.pulse_mobile_menu_profile_link_item .resizer li{
  margin-left:0.3125rem;
}
[dir="rtl"] .pulse_mobile_menu_profile_link_item .resizer li{
  margin-left:0;
  margin-right:0.3125rem;
}
.pulse_mobile_menu_profile_link_item .resizer li a{
  border-width:0.0625rem;
  border-radius:0.3125rem;
  width:1.5rem;
  height:1.5rem;
  display:flex;
  align-items:center;
  justify-content:center;
  font-size:var(--theme-font-size-small);
}
.pulse_mobile_menu_profile_link_item .resizer li.active a{
  background-color:var(--theme-button-background-color);
  color:var(--theme-button-font-color) !important;
}
.pulse_mobile_menu_profile_link_item .resizer li a:hover{
  text-decoration:none;
}
.pulse_mobile_menu_profile_section_footer a{
  width:100%;
}
/*Notification & Messages*/
.pulse_mobile_menu_notification,
.pulse_mobile_menu_messages{
	padding:0;
}
.pulse_mobile_menu_notification > ul > li,
.pulse_mobile_menu_messages > ul > li{
	display:flex;
	padding:10px 15px;
}
.pulse_mobile_menu_notification > ul > li.notifications_unread,
.pulse_mobile_menu_messages > ul > li.pulldown_content_list_highlighted{
  background-color:var(--theme-list-background-color-hover);
}
.pulse_mobile_menu_options{
  border-top-width:1px;
  padding:15px;
  display:flex;
  justify-content:space-around;
}
.pulse_mobile_menu_options a{
  font-weight:var(--theme-font-weight-bold);
}
@media (max-width:767px) {
	.pulse_mobile_menu{
		display:block;
	}
}
/*Mobile Tab Menu End*/