<?php
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/

$files = Engine_Api::_()->getDbTable('files', 'core')->getFilesAssoc();

return array(
	array(
		'title' => 'Pulse Theme - Header',
		'description' => 'This widget displays the header of the website.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.header',
		"autoEdit" => false,
	),
	array(
		'title' => 'Pulse Theme - Footer',
		'description' => 'This widget displays the Footer of the website.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.footer',
		"autoEdit" => false,
	),
	array(
		'title' => 'Pulse Theme - Mobile Tab Bar',
		'description' => 'Displays a mobile bottom navigation tab bar on the mobile view',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.mobile-menu',
		"autoEdit" => true,
	),
	array(
		'title' => 'Pulse Theme - Landing Page Main Section',
		'description' => 'This widget displays Landing Page Main Section.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-main',
		"autoEdit" => true,
		'adminForm' => array(
			'elements' => array(
				array(
					'Text',
					'title',
					array(
						'label' => 'Enter title of this widget.',
						'value' => 'Welcome to Socialengine',
					),
				),
				array(
					'Text',
					'heading',
					array(
						'label' => 'Enter heading of this widget.',
						'value' => 'Share Your World Effortlessly',
					),
				),
				array(
					'Text',
					'description',
					array(
						'label' => 'Enter description of this widget.',
						'value' => 'Experience a modern timeline, powerful groups, expressive profiles, and everything you need to stay connected.'
					),
				),
				array(
					'Text',
					'androidapplink',
					array(
						'label' => 'Enter play store link of Android App.',
						'value' => '#',
					),
				),
				array(
					'Text',
					'iosapplink',
					array(
						'label' => 'Enter app store link of iOS App.',
						'value' => '#',
					),
				),
			)
		),
	),
	array(
		'title' => 'Pulse Landing Page Banner Section',
		'description' => 'Displays the banner on the Landing Page. Requires that you have at least one banner. Edit this widget to configure various settings.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-banner',
		'adminForm' => 'Pulse_Form_Admin_Widget_LandingPageBanner',
		"autoEdit" => true,
	),
	array(
		'title' => 'Pulse Theme - Landing Page Features',
		'description' => 'This widget displays the feature blocks on the Landing Page. Edit this widget to configure features.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-features',
		'adminForm' => 'Pulse_Form_Admin_Widget_LandingPageFeatures',
		"autoEdit" => true,
	),
	array(
		'title' => 'Pulse Theme - Landing Page Services',
		'description' => 'This widget displays the services on the Landing Page. Edit this widget to configure services.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-service',
		'adminForm' => 'Pulse_Form_Admin_Widget_LandingPageService',
		"autoEdit" => true,
	),
	array(
		'title' => 'Pulse Theme - Landing How Community Works Section',
		'description' => 'This widget displays a CTA section on the landing Page. Edit this widget to configure various settings.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-cta-section',
		'adminForm' => 'Pulse_Form_Admin_Widget_LandingPageCtaSection',
		"autoEdit" => true,
	),
	array(
		'title' => 'Pulse Theme - Landing Page Mobile Apps Section',
		'description' => 'This widget displays the mobile apps section the on Landing Page. Edit this widget to configure apps section.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-app-section',
		"autoEdit" => true,
		'adminForm' => array(
			'elements' => array(
				array(
					'Text',
					'title',
					array(
						'label' => 'Enter title of this widget.',
					),
				),
				array(
					'Text',
					'description',
					array(
						'label' => 'Enter description of this widget.',
					),
				),
				array(
					'Text',
					'androidapplink',
					array(
						'label' => 'Enter play store link of Android App.',
					),
				),
				array(
					'Text',
					'iosapplink',
					array(
						'label' => 'Enter app store link of iOS App.',
					),
				),
				array(
					'Select',
					'apprightimage',
					array(
						'label' => 'Choose the image to be shown in this widget. Note: You can add a new image from the "File & Media Manager" section.',
						'multiOptions' => $files,
						'value' => '',
					)
				),
			)
		),
	),
	array(
		'title' => 'Pulse Theme - Landing Page Blogs Section',
		'description' => 'This widget displays the blogs section the on Landing Page.',
		'category' => 'Pulse',
		'type' => 'widget',
		'name' => 'pulse.landing-page-blogs',
		"autoEdit" => true,
		'adminForm' => array(
			'elements' => array(
				array(
					'Text',
					'title',
					array(
						'label' => 'Enter title of this widget.',
					),
				),
			)
		),
	),
);
