<?php

/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
 */

class Pulse_IndexController extends Core_Controller_Action_Standard
{

	function fontAction()
	{
		if (!engine_count($_POST)) {
			echo false;
			die;
		}
		$font = $this->_getParam('size', '');
		$_SESSION['font_theme'] = $font;
		echo true;
		die;
	}
	
	function modeAction()
	{
		if (!engine_count($_POST)) {
			echo false;
			die;
		}
		$font = $this->_getParam('mode', '');
		$_SESSION['mode_theme'] = $font;
		echo true;
		die;
	}
}
