<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/
?>

<?php $allParams = $this->allParams; ?>
<div class="container">
  <div class="pulse_landingpage_app_section">
    <div class="pulse_landingpage_app_left">
      <?php if($allParams['title']) { ?> 
        <h3><?php echo $this->translate($allParams['title']); ?></h3>
      <?php } ?>
      <?php if(!empty($allParams['description'])) { ?>
        <p><?php echo $this->translate($allParams['description']); ?></p>
      <?php } ?> 
      <?php if(!empty($allParams['androidapplink']) || !empty($allParams['iosapplink'])) { ?>
        <div class="pulse_landingpage_app_links">
          <a href="<?php echo $allParams['androidapplink']; ?>" target="_blank"><img src="application/modules/Core/externals/images/android.png" height="44" width="152" alt="Android App"></a>
          <a href="<?php echo $allParams['iosapplink']; ?>"  target="_blank"><img src="application/modules/Core/externals/images/ios.png" height="44" width="152" alt="iOS App"></a>
        </div>
      <?php } ?>
    </div>
		<div class="pulse_landingpage_app_right">
			<?php if(!empty($allParams['apprightimage'])) { ?>
				<?php $path = Engine_Api::_()->core()->getFileUrl($allParams['apprightimage'], true); ?>
				<img src="<?php echo $path['image'] ?>" height="467" width="500" alt="<?php echo $path['alt_text'] ? $path['alt_text'] : 'Mobile App' ?>" />
			<?php } else { ?>
				<img src="<?php echo 'application/modules/Pulse/externals/images/mobile-app.png'; ?>" height="467" width="500" alt="Mobile App" />
			<?php } ?>
		</div>
  </div>
</div>  
