.light_mode{
--pulse-header-background-color:#FFFFFF;
--pulse-minimenu-links-color:#000000;
--pulse-minimenu-links-hover-color:#000000;
--pulse-minimenu-background-color:#F5F5F5;
--pulse-minimenu-background-hover-color:#E6EAFD;
--pulse-minimenu-search-background-color:#F5F7FB;
--pulse-minimenu-search-font-color:#4A536A;
--pulse-footer-background-color:#FFFFFF;
--pulse-footer-font-color:#2C2C2C;
--pulse-footer-links-color:#2C2C2C;
--pulse-footer-border-color:#FFFFFF;
--pulse-body-background-color:#F5F7FB;
--pulse-font-color:#20242E;
--pulse-font-color-light:#666666;
--pulse-links-color:#20242E;
--pulse-headline-color:#2C2C2C;
--pulse-border-color:#F1F1F1;
--pulse-box-background-color:#FFFFFF;
--pulse-box-background-color-alt:#F5F5F5;
--pulse-input-background-color:#FFFFFF;
--pulse-input-font-color:#4A536A;
--pulse-input-border-color:#F1F1F1;
--pulse-secondary-button-background-color:#F5F5F5;
--pulse-secondary-button-background-color-hover:#D8D8D8;
--pulse-secondary-button-font-color:#2C2C2C;
--pulse-secondary-button-font-color-hover:#2C2C2C;
--pulse-secondary-button-border-color:#F0F0F0;
--pulse-secondary-button-border-color-hover:#D8D8D8;
--pulse-comments-background-color:#FDFDFD;
--theme-layout-box-shadow :2px 2px 40px -10px #0000000f;
}

.dark_mode{
  --pulse-header-background-color:#2C2C2C;
  --pulse-minimenu-links-color:#FFFFFF;
  --pulse-minimenu-links-hover-color:#FFFFFF;
  --pulse-minimenu-background-color:#3D3E3F;
  --pulse-minimenu-background-hover-color:#505255;
  --pulse-minimenu-search-background-color:#3D3E3F;
  --pulse-minimenu-search-font-color:#FFFFFF;
  --pulse-footer-background-color:#111111;
  --pulse-footer-font-color:#FFFFFF;
  --pulse-footer-links-color:#FFFFFF;
  --pulse-footer-border-color:#464444;
  --pulse-body-background-color:#222222;
  --pulse-font-color:#FFFFFF;
  --pulse-font-color-light:#F1F1F1;
  --pulse-headline-color:#FFFFFF;
  --pulse-links-color:#fff;
  --pulse-border-color:#464444;
  --pulse-box-background-color:#2C2C2C;
  --pulse-box-background-color-alt:#2F2F2F;
  --pulse-input-background-color:#2C2C2C;
  --pulse-input-font-color:#FFFFFF;
  --pulse-input-border-color:#464444;
  --pulse-secondary-button-background-color:#343536;
  --pulse-secondary-button-background-color-hover:#4C4D4E;
  --pulse-secondary-button-font-color:#E4E6EB;
  --pulse-secondary-button-font-color-hover:#DBDBDB;
  --pulse-secondary-button-border-color:#343536;
  --pulse-secondary-button-border-color-hover:#4C4D4E;
  --pulse-comments-background-color:#404040;
  --theme-layout-box-shadow :2px 2px 40px -10px #0000000f;
}
/*
DEFAULT STYLES FOR THIS --theme
*/
:root {
  /*
  PAGE WIDTHS & BACKGROUND COLOR
  Specify the top bar wrapper width (which contains the mini menu, logo, and main menu
  by default), the footer width, and the width of left & right-side columns.
  */
  --theme-main-width:1300px;
  --theme-header-menu-width:100%;
  --theme-content-width:var(--theme-main-width);
  --theme-content-columns-left-width:330px;
  --theme-content-columns-right-width:330px;
  --theme-body-background-color:var(--pulse-body-background-color);
  --theme-color:var(--pulse-theme-color);
  /*
  HEADER AND FOOTER COLORS
  These values are only used to style the site-wide header and footer.
  */
  --theme-header-background-color:var(--pulse-header-background-color);
  --theme-header-menu-background-color:var(--pulse-mainmenu-background-color);
  --theme-header-menu-link-background-color:transparent;
  --theme-header-menu-link-background-color-hover:transparent;
  --theme-header-menu-link-color:var(--pulse-mainmenu-links-color);
  --theme-header-menu-link-hover-color:var(--pulse-mainmenu-links-hover-color);
  --theme-header-minimenu-link-color:transparent;
	--theme-header-minimenu-link-background-color:transparent;
	--theme-header-minimenu-signup-background-color:var(--pulse-minimenu-signup-background-color);
	--theme-header-minimenu-signup-font-color:var(--pulse-minimenu-signup-font-color);
  --theme-header-search-background-color:var(--pulse-minimenu-search-background-color);
  --theme-header-search-font-color:var(--pulse-minimenu-search-font-color);

  --theme-footer-background-color:var(--pulse-footer-background-color);
  --theme-footer-font-color:var(--pulse-footer-font-color);
  --theme-footer-link-color:var(--pulse-footer-links-color);
  --theme-footer-border-color:var(--pulse-footer-border-color);
  /*
  TEXT & LINKS
  These values affect the size and colors of your text and links throughout your layout.
  */
  --theme-font-color:var(--pulse-font-color);
  --theme-font-color-light:var(--pulse-font-color-light);
  --theme-link-color:var(--pulse-links-color);
  --theme-link-color-hover:var(--pulse-links-hover-color);
  --theme-headline-color:var(--pulse-headline-color);
  --theme-border-color:var(--pulse-border-color);
  /*
  INPUT FIELDS AND BUTTONS
  These values style input fields and buttons that appear throughout the layout.
  */
  --theme-input-background-color:var(--pulse-input-background-color);
  --theme-input-font-color:var(--pulse-input-font-color);
  --theme-input-border-color:var(--pulse-input-border-color);
  --theme-button-background-color:var(--pulse-button-background-color);
  --theme-button-background-color-hover:var(--pulse-button-background-color-hover);
  --theme-button-font-color:var(--pulse-button-font-color);
  --theme-button-font-color-hover:var(--pulse-button-font-color-hover);
  --theme-button-border-color:var(--pulse-button-border-color);
  --theme-button-border-color-hover:var(--pulse-button-border-color-hover);
  --theme-secondary-button-background-color:var(--pulse-secondary-button-background-color);
  --theme-secondary-button-background-color-hover:var(--pulse-secondary-button-background-color-hover);
  --theme-secondary-button-font-color:var(--pulse-secondary-button-font-color);
  --theme-secondary-button-font-color-hover:var(--pulse-secondary-button-font-color-hover);
  --theme-secondary-button-border-color:var(--pulse-secondary-button-border-color);
  --theme-secondary-button-border-color-hover:var(--pulse-secondary-button-border-color-hover);
  /*
  TABS (BUTTON-STYLE)
  These colors are applied to the button-style tab menus which are often shown
  on browse pages.
  */
	--theme-buttontabs-font-color:var(--pulse-font-color);
	--theme-buttontabs-font-color-hover:var(--pulse-theme-color);
	--theme-buttontabs-font-color-active:var(--pulse-theme-color);
	--theme-buttontabs-border-color:transparent;
	--theme-buttontabs-border-color-active:var(--pulse-theme-color);
  /*
  TABS
  These colors are applied to tab menus (as seen on several pages, including
  the member profile page).
  */
  --theme-tabs-background-color:var(--pulse-box-background-color);
  --theme-tabs-background-color-active:var(--pulse-button-background-color);
  --theme-tabs-font-color:var(--theme-font-color);
  --theme-tabs-font-color-active:var(--pulse-button-font-color);
  --theme-tabs-border-color:transparent;
  --theme-tabs-border-color-hover:var(--pulse-theme-color);
  --theme-tabs-border-color-active:var(--pulse-theme-color);
  /*
  LISTS
  These colors are applied to some lists, especially in pull-down menus.
  */
  --theme-list-background-color:var(--pulse-box-background-color);
  --theme-list-background-color-alt:var(--pulse-box-background-color-alt);
  --theme-list-background-color-hover:var(--pulse-box-background-color-alt);
  --theme-comments-background-color:var(--pulse-comments-background-color);
  /*
  TAGS
  These colors are applied to tags, which appear on blogs, messages, etc.
  */
  --theme-tag-background-color:var(--theme-secondary-button-background-color);
  --theme-tag-font-color:var(--theme-secondary-button-font-color);
  /*
  INLINE PULLDOWN MENUS
  These colors style the inline pulldown menus that appear throughout the layout.
  */
  --theme-pulldown-background-color:var(--theme-list-background-color);
  --theme-pulldown-background-color-hover:var(--theme-button-background-color);
	--theme-pulldown-background-color-active:var(--theme-button-background-color);
  --theme-pulldown-font-color-active:var(--theme-button-font-color);
  --theme-pulldown-border-color:var(--theme-border-color);
  --theme-pulldown-contents-background-color:var(--theme-list-background-color);
  --theme-pulldown-contents-list-background-color-hover:var(--theme-list-background-color-hover);
  --theme-pulldown-contents-list-background-color-active:var(--theme-list-background-color-hover);
  --theme-pulldown-contents-list-font-color-active:var(--theme-font-color);
  
  /*Font Size*/
  --theme-font-size:var(--pulse-body-fontsize);
	--theme-font-size-small:12px;
  --theme-headline-size-large:1.5rem;
  --theme-headline-size-medium:var(--pulse-heading-fontsize);
  --theme-title-size:var(--theme-font-size);
  --theme-menu-link-size:var(--theme-body-font-size);
  --theme-tabs-font-size:var(--pulse-tab-fontsize);
  --theme-font-weight-bold:500;

  /*Font Family*/
  --theme-font-family:var(--pulse-body-fontfamily);
	--theme-heading-font-family:var(--pulse-heading-fontfamily);
  --theme-header-menu-font-family:var(--pulse-mainmenu-fontfamily);
	--theme-buttontabs-font-family:var(--pulse-tab-fontfamily);
  --theme-tabs-font-family:var(--pulse-tab-fontfamily);
  
  --theme-item-spacing:0.625rem;
  --theme-item-radius:0.75rem;
  --theme-item-transition:all .2s ease-in-out;
  --theme-item-shadow:0 0 5px rgba(0, 0, 0, .1);
  --theme-item-shadow-hover:0 0 5px rgba(0, 0, 0, .2);
  --theme-widget-spacing:20px;
  --theme-widget-radius:var(--themewidget-radius);
  --theme-header-inner-spacing:0.9375rem;
  --theme-sidebar-width:250px;
  

  --theme-secondary-font-color:#575757;
  --theme-header-height:70px;
  --theme-border-width:0.0375rem;
  --theme-layout-box-shadow :2px 2px 40px -10px #0000000f;
  --theme-dropdown-radius:20px;
  --theme-dropdown-box-shadow:4px 4px 16px 0px #00000033;
}
.color_scheme_3,
.dark_mode{
  --theme-layout-box-shadow:none;
}
.light_mode .color_scheme_3{
  --theme-layout-box-shadow:var(--theme-layout-box-shadow);
}
@media (max-width:768px) {  
  :root{
    --theme-widget-radius:0px
  }
}
@media (max-width:1199px) {  
  :root{
    --theme-main-width:100%;
    --theme-content-columns-left-width:250px;
    --theme-content-columns-right-width:250px;
  }
}
@media (min-width:1200px) { 
  :root{
    --theme-main-width:1140px;
    --theme-content-columns-left-width:300px;
    --theme-content-columns-right-width:300px;
  }
}
@media (min-width:1400px) { 
  :root{
    --theme-main-width:1320px;
    --theme-content-columns-left-width:300px;
    --theme-content-columns-right-width:300px;
  }
}