

@media (max-width:1199px){
  
  /*LAYOUT*/
  .layout_right,
  .layout_left{
    width:250px;
  }
  #global_content .layout_main{
    gap:0;
  }
  div.layout_page_footer .layout_main{
    padding-left:0;
    padding-right:0;
  }
  #global_wrapper{
    margin-inline:0;
  }
  #global_footer{
    margin-inline:0;
  }

  /*HEADER*/
  .layout_page_header .container{
    width:100%;
    padding:0 0.9375rem;
  }
  .layout_core_search_mini #global_search_field:focus-visible,
  .layout_core_search_mini .focused #global_search_field{
    width:100%;
  }
  .header_main_menu_close {
    display:none;
  }
  .main_navigation{
    left:-100%;
  }
  [dir="rtl"] .main_navigation{
    right:-100%;
    left:auto;
  }
  .header_body_open .main_navigation{
    left:0;
  }
  [dir="rtl"] .header_body_open .main_navigation{
    left:auto;
    right:0;
  }
}
@media (max-width:1024px){
  .tabs_alt .more_tab > a{
    display:block !important;
  }
div#global_content{
    padding-left:0.625rem;
    padding-right:0.625rem;
  }
  /*Header Page*/

  .layout_page_header{
    backdrop-filter:none;
  }
  .pulse_header{
    padding:15px 10px;
    height:inherit;
  }
  .layout_page_header .container{
    padding:0;
  }
  .header_left,
  .header_right {
    width:auto;
  }
  .minimenu_guest > ul > li + li{
    margin-left:0.3125rem !important;
  }
  [dir="rtl"] .minimenu_guest > ul > li + li{
    margin-left:0 !important;
    margin-right:0.3125rem !important;
  }
  #core_menu_mini_menu > ul > li{
    margin-left:0.375rem;
  }
  [dir="rtl"] #core_menu_mini_menu > ul > li{
    margin-left:0;
    margin-right:0.375rem;
  }
  .guest-user #core_menu_mini_menu > ul > li{
    width:auto;
  }
  .guest-user #core_menu_mini_menu > ul > li > a.show_icons i{
    margin-bottom:0 !important;
  }
  #core_menu_mini_menu > ul .core_mini_auth.show_icons span._linktxt,
  #core_menu_mini_menu > ul .core_mini_signup.show_icons span._linktxt{
    display:inline-block;
  }
  /*Footer*/
  .pulse_footer .row > .col-md-5{
    width:100%;
    margin-bottom:0.9375rem;
  }
  .pulse_footer .col-md-2{
    width:33.33%;
  }
}
@media (min-width:768px) and (max-width:1024px){
  .layout_right, .layout_left{
    float:left;
    clear:both;
  }
  [dir="rtl"] .layout_right, 
  [dir="rtl"] .layout_left{
    float:right;
  }
}
@media(max-width:767px){
  h1 {
    font-size:1.1rem;
  }
  #global_content .layout_main{
    display:flex;
    flex-direction:column;
    gap:0;
  }
  #global_page_user-index-home.has-sidebar #show-sidebar{
    margin-left:0.3125rem;
    margin-right:0.3125rem;
    margin-bottom:0.9375rem;
  }
  .layout_left, 
  .layout_right{
    width:100%;
    float:left;
    padding-left:0;
    padding-right:0;
    margin-left:0;
    margin-right:0;
    display:none;
  }
  [dir="rtl"] .layout_left,
  [dir="rtl"] .layout_right{
    padding-left:0;
    padding-right:0;
  }
  #global_page_user-index-home.has-sidebar #show-sidebar,
  #global_page_user-index-home .layout_right,
  #global_page_user-index-home .layout_left {
    display: none !important;
  }
  .layout_middle{
    width:100%;
    padding:0;
  }
  div#global_content{
    padding-left:0;
    padding-right:0;
  }
  .layout_left > div > .generic_layout_container,
  .layout_middle > .generic_layout_container,
  .layout_right > div > .generic_layout_container,
  .generic_layout_container > h3,
  .profile_cover_wrapper,
  .profile_cover_photo,
  .user_setting_main_page_main .layout_left > div,
  .user_setting_main_page_main .layout_right > div,
  .layout_user_user_setting_cover_photo,
  .layout_page_user_auth_login,
  .layout_core_banner > div,
  .profile_cover_photo_empty{
    border-radius:0 !important;
  }
  .layout_user_user_setting_cover_photo {
    margin-bottom:var(--theme-widget-spacing) !important;
  }
  .layout_middle > .generic_layout_container {
    border-radius:var(--theme-widget-radius) !important;
  }
  #global_wrapper .layout_middle .generic_layout_container.layout_core_content{
    padding:0.625rem;
  }
  .generic_layout_container > h3,
  .layout_content > h2,
  .layout_content > h3{
    margin:-0.625rem -0.625rem 0.625rem;
  }
  /*Header*/
  .layout_page_header .layout_main{
    display:flex;
    flex-direction:column;
  }
  .pulse_header{
    padding:10px;
    min-height:60px;
    display:flex;
    align-items:center;
  }
  .pulse_header_inner{
    gap:10px;
  }
  .header_left{
    order:1;
    flex:1;
  }
  .header_logo a,
  .header_logo_contrast a{
    font-size:1rem;
  }
  .header_logo a:hover,
  .header_logo_contrast a:hover{
    text-decoration:none;
  }
  .header_logo img{
    max-height:40px;
  }
  .header_right{
    /* margin-right:3.125rem; */
    order:2;
  }
  /* [dir="rtl"] .header_right{
    margin-right:0.9375rem;
    margin-left:3.125rem;
   } */
  .guest-user #core_menu_mini_menu > ul{
    min-width:inherit !important;
  }
   #core_menu_mini_menu > ul > li,
   [dir="rtl"] #core_menu_mini_menu > ul > li{
     margin-left:0px;
     margin-right:0 ;
     position:inherit !important;
     min-width:inherit;
   }
  #core_menu_mini_menu.minimenu_guest > ul > li{
    margin-left:10px !important;
  }
  #core_menu_mini_menu > ul > li#core_menu_mini_menu_update,
  #core_menu_mini_menu > ul > li.core_mini_messages,
  #core_menu_mini_menu > ul > li.core_mini_menu_profile,
  #core_menu_mini_menu > ul > li.core_mini_language,
  #core_menu_mini_menu > ul > li.core_mini_menu_accessibility,
  #core_menu_mini_menu > ul > li#core_mini_auth,
  #core_menu_mini_menu > ul > li#core_mini_signup{
    display:none !important;
  }
  .header_search_wrap{
    order:3;
    flex:inherit;
  }
  .header_mobile_menu{
    order:4;
    display:block;
  }
  .header_search{
    margin:0;
  }
  .header_search .search_mobile_btn,
  .header_mobile_menu a{
    /* position:absolute;
    right:0.625rem;
    top:10px; */
    width:40px;
    height:40px;
    display:flex !important;
    align-items:center;
    justify-content:center;
    border-width:0 !important;
    padding:0 !important;
    color:var(--pulse-minimenu-links-color) !important;
    background-color:var(--pulse-minimenu-background-color) !important;
    border-radius:50%;
  }
  /* [dir="rtl"] .header_search .search_mobile_btn{
    right:auto;
    left:0.625rem;
  } */
  .header_search .search_mobile_btn i,
  .header_mobile_menu a i{
    color:var(--pulse-minimenu-links-color) !important;
    height:25px;
    width:25px;
    font-size:16px;
    display:flex;
    align-items:center;
    justify-content:center;
  }
  #core_menu_mini_menu > ul > li a.show_icons{
    width:40px !important;
    height:40px !important;
  }
  #core_menu_mini_menu > ul > li .show_icons i.minimenu_icon:before{
    font-size:16px !important;
  }
  .layout_core_search_mini .core_search_form_wrap{
    background-color:var(--theme-header-background-color);
    padding:10px;
    position:absolute;
    top:58px;
    left:0;
    right:0;
    z-index:9;
    display:none;
  }
  .layout_core_search_mini .core_search_form_wrap.search_mobile_btn_active{
    box-shadow:0 0.3125rem 0.1875rem rgba(17, 24, 39, .1);
    background-color:var(--theme-header-background-color);
    max-width:100% !important;
    display:block;
    width:100%;
  }
  .layout_core_search_mini #global_search_form input{
    margin:0;
    width:100%;
    max-width:100%;
  }
  .pulse_header_mainmenu_dropdown_container{
    display:none !important;
  }

  
  /*Profile Tabs */
  .layout_core_container_tabs{
    position:relative;
  }
  .layout_core_container_tabs > .generic_layout_container > h3,
  div.tabs_alt .tab_collapsed_action{
    display:none !important;
  }
  div.tabs_alt > ul{
    overflow:auto;
    flex-wrap:nowrap;
    border-radius:0;
    border:0;
  }
  div.tabs_alt >ul > li{
    display:block;
  }
  div.tabs_alt > ul > li > a{
    display:block;
  }
  div.tabs_alt > ul > li.tab_active > a, 
  div.tabs_alt > ul > li.active > a, 
  div.tabs_alt > ul > li:hover > a, 
  div.tabs_alt > ul > li.active:hover > a{
    border-width:0;
    top:0;
    display:block;
  }
  div.tabs_alt li.more_tab{
    background-color:transparent !important;
  }
  .tabs_alt > ul > li.tab_open .tab_pulldown_contents_wrapper{
    right:0;
  }
  [dir="rtl"] .tabs_alt > ul > li.tab_open .tab_pulldown_contents_wrapper{
    left:0;
    right:auto;
  }
  div.tabs > ul, 
  div.tabs_alt > ul{
    padding:0px 15px;
    scrollbar-width: none;
    -ms-overflow-style: none;
  }
  div.tabs > ul::-webkit-scrollbar,
  div.tabs_alt > ul::-webkit-scrollbar{
    display:none;
  }
  .generic_layout_container .headline {
    flex-direction:column;
    align-items:flex-start;
    gap:0.625rem;
  }
  .generic_layout_container .headline .tabs > ul {
    padding:0 !important;
    flex-wrap:nowrap;
  }
  .headline h2{
    font-size:1.2rem;
    padding:0;
  }
  .tabs > ul > li > a{
    padding:0;
  }
  .profile_cover_photo_wrapper,
  .shimmer_profile_cover_photo_wrapper{
    height:13.75rem !important;
  }
  .global_form div.form-label{
    padding-top:0;
  }
  /*Footer*/
  body:not(.guest-user) #global_footer{
    margin-bottom:60px;
  }
  body:not(.guest-user).player_enable #global_footer{
    margin-bottom:147px;
  }
  body:not(.guest-user).player_enable .sesmusic_player_wrapper{
    bottom:60px;
  }
  body:not(.guest-user).player_enable .sesmusic_player{
    border-block-end-width:1px;
    box-shadow:none;
  }
  body:not(.guest-user).player_enable .emailverfication_tip{
    bottom: 147px;
  }
  .pulse_footer{
    padding:1.875rem 0 0.9375rem;
  }
  .pulse_footer_logo{
    margin-bottom:0.5rem;
  }
  .pulse_footer_left p{
    font-size:0.9rem;
  }
  .pulse_footer_link,
  .pulse_footer_contact{
    margin-top:25px;
  }
  .pulse_footer .col-md-2{
    width:50%;
  }
  .pulse_footer_bottom {
    margin-top:15px;
  }
  .pulse_footer .custom_footer_heading{
    font-size:1rem;
    padding:0 0 0.3125rem;
    margin-bottom:0;
  }
  .footer_link_bottom{
    margin-top:0.9375rem;
  }
  .footer_link_bottom li a{
    margin-top:0.625rem;
    font-size:0.875rem;
  }
  .pulse_footer_bottom_inner{
    flex-direction:column;
    gap:5px;
  }
  .pulse_footer_bottom_left{
    flex-wrap:wrap;
    justify-content:center;
    gap:5px;
  }
  .pulse_footer_bottom_left .footer_donotsell{
    margin-bottom:0.3125rem;
  }
  .pulse_footer_bottom_left .footer_copyright,
  [dir="rtl"] .pulse_footer_bottom_left .footer_copyright{
    margin:0;
  }
  .pulse_footer_bottom_right,
  [dir="rtl"] .pulse_footer_bottom_right{
    margin:0;
  }
  .pulse_footer_bottom_right .menu_core_footer::after{
    width:0.25rem;
    height:0.25rem;
    top:0.5rem;
  }
  /*Forgot Page*/
  .layout_page_user_auth_forgot{
    width:100%;
  }
  /*Login Page*/
  #global_page_core-error-requireuser #global_content .layout_core_content{
    margin-top:0;
  }
  .user_login_page .user_login_form{
    border-radius:0;
    border:0;
    padding:0px;
    background:transparent;
  }
  .layout_page_user_auth_login{
    width:100%;
  }
  .user_login_page .user_login_form > h3{
    font-size:1.3rem;
  }
  .authpage #global_content .layout_core_content .global_form h3 {
    font-size:1.3rem;
  }
  .user_login_page #user_form_login .user_showhidepassword > i{
    margin-top:-2.5rem;
  }
  .required_login_form .global_form .user_showhidepassword > i{
    margin-top:-3rem;
  }
  /*Form*/
  .global_form > div > div h3{
    margin:-0.625rem -0.625rem 0.625rem;
    padding:0.9375rem 0.625rem;
  }
  .global_form_wrap .global_form > div .form-elements{
    padding:0;
  }
  .global_form div.form-wrapper{
    gap:5px;
  }
  .global_form div.form-element{
    min-width:100%;
    max-width:100%;
  }
  html .global_form > div,
  html input[type=text],
  html input[type=email],
  html input[type=password],
  html input.text,
  html textarea, html select,
  html .global_form div.form-element,
  html .global_form div>p,
  html .search_result{
    width:100% !important;
    min-width:100% !important;
    max-width:100% !important;
  }  
  .user_login_form .user_showhidepassword > i{
    font-size:0.875rem;
  }
  .global_form div#starttime-element,
  .global_form div#endtime-element{
    flex-wrap:wrap;
  }
  .global_form div#starttime-element .event_calendar_container,
  .global_form div#endtime-element .event_calendar_container{
    width:100% !important;
    max-width:100%;
  }
  .global_form div#starttime-element select,
  .global_form div#endtime-element select{
    width:30% !important;
    max-width:inherit !important;
    min-width:auto !important;
  }
  .intopenai_form_element .form-label{
    display:none;
  }
  .manage_search #integer-wrapper{
    width:100%;
  }
  .activity_feed_filters > ul {
    padding:0px 10px;
    justify-content:flex-start;
  }

  /* activity notification page  */
  .notifications_layout {
    margin:0px 10px !important;
  }
  .layout_stories_all_stories h3{
    padding-inline:10px;
  }
  ul.feed .feed_item_icon > ul > li > a i{
    background-size:22px;
    height:22px;
    width:22px;
  }
  ul.feed .feed_item_icon > ul > li.feed_votebtn > a i{
    padding:4px;
  }
  ul.feed .feed_item_icon > ul > li > a span{
    display:none !important;
  }
  .layout_top .layout_core_banner{
    height:auto;
  }
  .layout_top .layout_core_banner > div{
    position:relative;
    height:auto;;
  }
  .layout_core_banner > div > section h1{
    font-size:1.25rem;
  }
  .layout_core_banner > div > section article{
    font-size: var(--theme-font-size);
    width:100%;
  }
  .layout_top .layout_core_banner + .generic_layout_container{
    margin-top:0;
  }
  .browse_mambers_list_item article {
    border:0;
    box-shadow:var(--theme-layout-box-shadow);
  }
  #global_page_user-profile-index .layout_core_container_tabs > .generic_layout_container {
    border-radius:0 !important;
    border:0;
  }

  /*Floating Icons*/

  html .sesmusic_create_btn{
    bottom:120px;
  }
  html a.sesbasic_scrollup_button{
    bottom:70px;
  }
  html .player_enable .sesmusic_create_btn{
    bottom:210px !important;
  }
  html .player_enable a.sesbasic_scrollup_button{
    bottom:160px !important;
  }
}
@media(min-width:768px) and (max-width:991px) {
  .pulse_footer_left {
    margin-bottom:20px;
  }
}
@media(min-width:1024px) and (max-width:1400px){
  .layout_right,
  .layout_left{
    width:250px;
  }
  #global_content .layout_main {
    gap:0;
  }
}
html .global_form_wrap .global_form > div{
  container-type: inline-size;
  container-name: layout;
}
@container (max-width: 1200px) {
  .global_form div.form-element {
    min-width: 500px;
    max-width: 500px;
  }
}
@container (max-width: 800px) {
  .global_form div.form-element {
    min-width: 100%;
    max-width: 100%;
  }
}