<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/

class Pulse_Widget_FooterController extends Engine_Content_Widget_Abstract {

  public function indexAction() {
  
    $setting = Engine_Api::_()->getApi('settings', 'core');
    $menuApi = Engine_Api::_()->getApi('menus', 'core');
    
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer->getIdentity();
    
    //Aboutus Links
    $this->view->aboutLinksMenu = $menuApi->getNavigation('pulse_aboutlinks_footer');

    //Quick Links
    $this->view->quickLinksMenu = $menuApi->getNavigation('pulse_quicklinks_footer');
    
    //Footer Links
    $this->view->navigation = $menuApi->getNavigation('core_footer');

    //Languages
    $this->view->languageNameList = Engine_Api::_()->getApi('languages', 'core')->getLanguages();
    
    // Social Links
    $this->view->socialnavigation = $menuApi->getNavigation('core_social_sites');
    // Footer Contrast
    $this->view->accessibility_option = $setting->getSetting("accessibility_options");
    $this->view->footerlogocontrast = $setting->getSetting("pulse_footer_logocontrast");
    
    $this->view->footerbgimage = $setting->getSetting("pulse.footer.bgimage");
    $this->view->footerbgphotocontrast = $setting->getSetting("pulse.footer.bgphotocontrast");

  }
}
