/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/

INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES ("core_admin_main_plugins_pulse", "pulse", "Pulse Theme", "", '{"route":"admin_default","module":"pulse","controller":"settings"}', "core_admin_main_plugins", "", 999),
("core_admin_main_pulse", "pulse", "Pulse Theme", "", '{"route":"admin_default","module":"pulse","controller":"settings"}', "core_admin_main", "", 999),
("pulse_admin_main_settings", "pulse", "Global Settings", "", '{"route":"admin_default","module":"pulse","controller":"settings"}', "pulse_admin_main", "", 1);


INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
("pulse_admin_main_footer", "pulse", "Footer Settings", "", '{"route":"admin_default","module":"pulse","controller":"settings", "action":"footer"}', "pulse_admin_main", "", 2),
("pulse_admin_main_styling", "pulse", "Color Schemes", "", '{"route":"admin_default","module":"pulse","controller":"settings", "action":"styling"}', "pulse_admin_main", "", 3),
("pulse_admin_main_managefonts", "pulse", "Manage Fonts", "", '{"route":"admin_default","module":"pulse","controller":"settings", "action":"manage-fonts"}', "pulse_admin_main", "", 4),
("pulse_admin_main_customcss", "pulse", "Custom CSS", "", '{"route":"admin_default","module":"pulse","controller":"custom-theme", "action":"index"}', "pulse_admin_main", "", 5);

INSERT IGNORE INTO `engine4_core_menus` (`name`, `type`, `title`, `order`) VALUES
("pulse_quicklinks_footer", "standard", "Pulse Theme - Footer Quicklinks", 1),
("pulse_aboutlinks_footer", "standard", "Pulse Theme - Footer Explore Links", 2);

DROP TABLE IF EXISTS `engine4_pulse_customthemes`;
CREATE TABLE IF NOT EXISTS `engine4_pulse_customthemes` (
	`customtheme_id` int(11) NOT NULL AUTO_INCREMENT,
	`name` varchar(128) NOT NULL,
	`value` varchar(32) NOT NULL,
	`column_key` varchar(128) NOT NULL,
	`theme_id` int(11) NOT NULL,
	`default` TINYINT(1) NOT NULL DEFAULT "0" ,
	PRIMARY KEY (`customtheme_id`),
	UNIQUE KEY `UNIQUEKEY` (`column_key`,`theme_id`,`default`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;

INSERT IGNORE INTO `engine4_pulse_customthemes` (`name`, `value`, `column_key`, `theme_id`, `default`) VALUES
("Theme - 1", "1", "theme_color", 1, 0),
("Theme - 1", "1", "custom_theme_color", 1, 0),
("Theme - 1", "#ffffff", "pulse_header_background_color", 1, 0),
("Theme - 1", "#000000", "pulse_minimenu_links_color", 1, 0),
("Theme - 1", "#000000", "pulse_minimenu_links_hover_color", 1, 0),
("Theme - 1", "#F5F5F5", "pulse_minimenu_background_color", 1, 0),
("Theme - 1", "#E6EAFD", "pulse_minimenu_background_hover_color", 1, 0),
("Theme - 1", "#F5F7FB", "pulse_minimenu_search_background_color", 1, 0),
("Theme - 1", "#4A536A", "pulse_minimenu_search_font_color", 1, 0),
("Theme - 1", "#ffffff", "pulse_footer_background_color", 1, 0),
("Theme - 1", "#2C2C2C", "pulse_footer_font_color", 1, 0),
("Theme - 1", "#2C2C2C", "pulse_footer_links_color", 1, 0),
("Theme - 1", "#FFFFFF", "pulse_footer_border_color", 1, 0),
("Theme - 1", "#5E72E4", "pulse_theme_color", 1, 0),
("Theme - 1", "#F5F7FB", "pulse_body_background_color", 1, 0),
("Theme - 1", "#20242E", "pulse_font_color", 1, 0),
("Theme - 1", "#666666", "pulse_font_color_light", 1, 0),
("Theme - 1", "#20242E", "pulse_links_color", 1, 0),
("Theme - 1", "#1976D2", "pulse_links_hover_color", 1, 0),
("Theme - 1", "#2C2C2C", "pulse_headline_color", 1, 0),
("Theme - 1", "#F1F1F1", "pulse_border_color", 1, 0),
("Theme - 1", "#FFFFFF", "pulse_box_background_color", 1, 0),
("Theme - 1", "#F5F5F5", "pulse_box_background_color_alt", 1, 0),
("Theme - 1", "#1F1F1F", "pulse_form_label_color", 1, 0),
("Theme - 1", "#FFFFFF", "pulse_input_background_color", 1, 0),
("Theme - 1", "#4A536A", "pulse_input_font_color", 1, 0),
("Theme - 1", "#F1F1F1", "pulse_input_border_color", 1, 0),
("Theme - 1", "#5E72E4", "pulse_button_background_color", 1, 0),
("Theme - 1", "#5D66E4", "pulse_button_background_color_hover", 1, 0),
("Theme - 1", "#FFFFFF", "pulse_button_font_color", 1, 0),
("Theme - 1", "#FFFFFF", "pulse_button_font_color_hover", 1, 0),
("Theme - 1", "#5E72E4", "pulse_button_border_color", 1, 0),
("Theme - 1", "#5D66E4", "pulse_button_border_color_hover", 1, 0),
("Theme - 1", "#F5F5F5", "pulse_secondary_button_background_color", 1, 0),
("Theme - 1", "#D8D8D8", "pulse_secondary_button_background_color_hover", 1, 0),
("Theme - 1", "#2C2C2C", "pulse_secondary_button_font_color", 1, 0),
("Theme - 1", "#2C2C2C", "pulse_secondary_button_font_color_hover", 1, 0),
("Theme - 1", "#F0F0F0", "pulse_secondary_button_border_color", 1, 0),
("Theme - 1", "#D8D8D8", "pulse_secondary_button_border_color_hover", 1, 0),
("Theme - 1", "#FDFDFD", "pulse_comments_background_color", 1, 0),

("Theme - 2", "2", "theme_color", 2, 0),
("Theme - 2", "2", "custom_theme_color", 2, 0),
("Theme - 2", "#ffffff", "pulse_header_background_color", 2, 0),
("Theme - 2", "#000000", "pulse_minimenu_links_color", 2, 0),
("Theme - 2", "#000000", "pulse_minimenu_links_hover_color", 2, 0),
("Theme - 2", "#F5F5F5", "pulse_minimenu_background_color", 2, 0),
("Theme - 2", "#efe8e5", "pulse_minimenu_background_hover_color", 2, 0),
("Theme - 2", "#F5F7FB", "pulse_minimenu_search_background_color", 2, 0),
("Theme - 2", "#4A536A", "pulse_minimenu_search_font_color", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_footer_background_color", 2, 0),
("Theme - 2", "#2C2C2C", "pulse_footer_font_color", 2, 0),
("Theme - 2", "#2C2C2C", "pulse_footer_links_color", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_footer_border_color", 2, 0),
("Theme - 2", "#FF6D37", "pulse_theme_color", 2, 0),
("Theme - 2", "#F5F7FB", "pulse_body_background_color", 2, 0),
("Theme - 2", "#20242E", "pulse_font_color", 2, 0),
("Theme - 2", "#666666", "pulse_font_color_light", 2, 0),
("Theme - 2", "#20242E", "pulse_links_color", 2, 0),
("Theme - 2", "#FF6D37", "pulse_links_hover_color", 2, 0),
("Theme - 2", "#2C2C2C", "pulse_headline_color", 2, 0),
("Theme - 2", "#F1F1F1", "pulse_border_color", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_box_background_color", 2, 0),
("Theme - 2", "#F5F5F5", "pulse_box_background_color_alt", 2, 0),
("Theme - 2", "#1F1F1F", "pulse_form_label_color", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_input_background_color", 2, 0),
("Theme - 2", "#4A536A", "pulse_input_font_color", 2, 0),
("Theme - 2", "#F1F1F1", "pulse_input_border_color", 2, 0),
("Theme - 2", "#FF6D37", "pulse_button_background_color", 2, 0),
("Theme - 2", "#f7713f", "pulse_button_background_color_hover", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_button_font_color", 2, 0),
("Theme - 2", "#FFFFFF", "pulse_button_font_color_hover", 2, 0),
("Theme - 2", "#FF6D37", "pulse_button_border_color", 2, 0),
("Theme - 2", "#f7713f", "pulse_button_border_color_hover", 2, 0),
("Theme - 2", "#F5F5F5", "pulse_secondary_button_background_color", 2, 0),
("Theme - 2", "#D8D8D8", "pulse_secondary_button_background_color_hover", 2, 0),
("Theme - 2", "#2C2C2C", "pulse_secondary_button_font_color", 2, 0),
("Theme - 2", "#2C2C2C", "pulse_secondary_button_font_color_hover", 2, 0),
("Theme - 2", "#F0F0F0", "pulse_secondary_button_border_color", 2, 0),
("Theme - 2", "#D8D8D8", "pulse_secondary_button_border_color_hover", 2, 0),
("Theme - 2", "#FDFDFD", "pulse_comments_background_color", 2, 0),

("Theme - 3", "3", "theme_color", 3, 0),
("Theme - 3", "3", "custom_theme_color", 3, 0),
("Theme - 3", "#2C2C2C", "pulse_header_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_minimenu_links_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_minimenu_links_hover_color", 3, 0),
("Theme - 3", "#3d3e3f", "pulse_minimenu_background_color", 3, 0),
("Theme - 3", "#343536", "pulse_minimenu_background_hover_color", 3, 0),
("Theme - 3", "#505255", "pulse_minimenu_search_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_minimenu_search_font_color", 3, 0),
("Theme - 3", "#111111", "pulse_footer_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_footer_font_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_footer_links_color", 3, 0),
("Theme - 3", "#464444", "pulse_footer_border_color", 3, 0),
("Theme - 3", "#5E72E4", "pulse_theme_color", 3, 0),
("Theme - 3", "#222222", "pulse_body_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_font_color", 3, 0),
("Theme - 3", "#F1F1F1", "pulse_font_color_light", 3, 0),
("Theme - 3", "#1976D2", "pulse_links_color", 3, 0),
("Theme - 3", "#1976D2", "pulse_links_hover_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_headline_color", 3, 0),
("Theme - 3", "#464444", "pulse_border_color", 3, 0),
("Theme - 3", "#2C2C2C", "pulse_box_background_color", 3, 0),
("Theme - 3", "#2F2F2F", "pulse_box_background_color_alt", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_form_label_color", 3, 0),
("Theme - 3", "#2C2C2C", "pulse_input_background_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_input_font_color", 3, 0),
("Theme - 3", "#464444", "pulse_input_border_color", 3, 0),
("Theme - 3", "#5E72E4", "pulse_button_background_color", 3, 0),
("Theme - 3", "#5E72E4", "pulse_button_background_color_hover", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_button_font_color", 3, 0),
("Theme - 3", "#FFFFFF", "pulse_button_font_color_hover", 3, 0),
("Theme - 3", "#5E72E4", "pulse_button_border_color", 3, 0),
("Theme - 3", "#5E72E4", "pulse_button_border_color_hover", 3, 0),
("Theme - 3", "#343536", "pulse_secondary_button_background_color", 3, 0),
("Theme - 3", "#4c4d4e", "pulse_secondary_button_background_color_hover", 3, 0),
("Theme - 3", "#e4e6eb", "pulse_secondary_button_font_color", 3, 0),
("Theme - 3", "#dbdbdb", "pulse_secondary_button_font_color_hover", 3, 0),
("Theme - 3", "#343536", "pulse_secondary_button_border_color", 3, 0),
("Theme - 3", "#4C4D4E", "pulse_secondary_button_border_color_hover", 3, 0),
("Theme - 3", "#404040", "pulse_comments_background_color", 3, 0);

UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fi fi-rr-bell"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_update";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fi fi-rs-circle-user"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_profile";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fi fi-rr-sign-in-alt"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_auth";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fi fi-rr-user-add"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_signup";
UPDATE `engine4_core_menuitems` SET `params` = '{"icon":"fi fi-rr-envelope"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_messages";
UPDATE `engine4_core_menuitems` SET `params` = '{"route":"default","module":"payment","icon":"fi fi-rr-dollar"}' WHERE `engine4_core_menuitems`.`name` = "core_mini_currency";

INSERT IGNORE INTO `engine4_core_settings` (`name`, `value`) VALUES
("pulse.aboutlinksenable", "1"),
("pulse.body.fontfamily", "Default Font"),
("pulse.body.fontsize", "0.875rem"),
("pulse.changelanding", "0"),
("pulse.dashboard.id", "2"),
("pulse.dashboardidmenu", "1"),
("pulse.description", "At our community we believe in the power of connections. Our platform is more than just a social networking site; it\'s a vibrant community where individuals from diverse backgrounds come together to share, connect, and thrive. We are dedicated to fostering creativity, building strong communities, and raising awareness on a global scale."),
("pulse.footer.enablelogo", "1"),
("pulse.footer.logo", ""),
("pulse.footer.logocontrast", ""),
("pulse.googlebody.fontfamily", '\"Poppins\"'),
("pulse.googlebody.fontfamilyvariants", "100,100italic,200,200italic,300,300italic,regular,italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic"),
("pulse.googlebody.fontsize", "0.875rem"),
("pulse.googlefonts", "1"),
("pulse.googleheading.fontfamily", '\"Poppins\"'),
("pulse.googleheading.fontfamilyvariants", "100,100italic,200,200italic,300,300italic,regular,italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic"),
("pulse.googleheading.fontsize", "1.0625rem"),
("pulse.googletab.fontfamily", '\"Poppins\"'),
("pulse.googletab.fontfamilyvariants", "100,100italic,200,200italic,300,300italic,regular,italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic"),
("pulse.googletab.fontsize", "0.875rem"),
('pulse.headerloggedinoptions', 'a:4:{i:0;s:6:"search";i:1;s:8:"miniMenu";i:2;s:8:"mainMenu";i:3;s:4:"logo";}'),
('pulse.headernonloggedinoptions', 'a:4:{i:0;s:6:"search";i:1;s:8:"miniMenu";i:2;s:8:"mainMenu";i:3;s:4:"logo";}'),
("pulse.heading.fontfamily", "Default Font"),
("pulse.heading.fontsize", "1.0625rem"),
("pulse.helpenable", "1"),
("pulse.logo", ""),
("pulse.logocontrast", ""),
("pulse.quicklinksenable", "1"),
("pulse.rightcolhdingemail", "info@abc.com"),
("pulse.rightcolhdinglocation", "Los Angeles, USA"),
("pulse.rightcolhdingphone", "1234567890"),
("pulse.socialenable", "1"),
("pulse.tab.fontfamily", "Default Font"),
("pulse.tab.fontsize", "0.875rem"),
("pulse.theme.color", "1");