<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<div class="pulse_landingpage_features">
  <div class="container">
    <div class="pulse_landingpage_features_section">
      <?php if ($allParams['title']) { ?>
        <h3 class="pulse_title"><?php echo $this->translate($allParams['title']); ?></h3>
      <?php } ?>
      <div class="pulse_landingpage_features_row">
        <?php for ($i = 1; $i <= 3; $i++) { ?>
          <?php if (!empty($allParams['featuresheading' . $i]) || !empty($allParams['headinglink' . $i]) || !empty($allParams['description' . $i])) { ?>
            <div class="pulse_landingpage_features_inner">
              <div class="pulse_landingpage_features_content">
                <?php if (!empty($allParams['featuresheading' . $i])) { ?>
                  <h4>
                    <?php echo $this->translate($allParams['featuresheading' . $i]); ?>
                  </h4>
                <?php } ?>
                <?php if (!empty($allParams['description' . $i])) { ?>
                  <p>
                    <?php echo $this->translate($allParams['description' . $i]); ?>
                  </p>
                <?php } ?>
              </div>
              <figure>
                <?php if(!empty($allParams['photo' . $i])) { ?>
                  <?php $path = Engine_Api::_()->core()->getFileUrl($allParams['photo' . $i], true); ?>
                  <img src="<?php echo $path['image']; ?>" height="" width="" alt="<?php echo $path['alt_text'] ? $path['alt_text'] : 'Features Icon'; ?>" />
                <?php } else { ?>
                  <img src="<?php echo 'application/modules/Pulse/externals/images/features/' . $i . '.png'; ?>" height="" width="" alt="Features Icon" />
                <?php } ?>
              </figure>
            </div>
          <?php } ?>
        <?php } ?>
      </div>
    </div>
  </div>
</div>