<?php
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/

return array (
  'package' =>
  array(
    'type' => 'module',
    'name' => 'pulse',
    'version' => '8.1.0',
    'dependencies' => array(
      array(
        'type' => 'module',
        'name' => 'core',
        'minVersion' => '8.0.0',
      ),
    ),
    'path' => 'application/modules/Pulse',
    'title' => 'Pulse Theme',
    'description' => 'Responsive, modern theme with features to delight you and your members!',
    'author' => '<a href="https://socialengine.com/" style="text-decoration:underline;" target="_blank">SocialEngine</a>',
    'thumb' => 'application/modules/Pulse/externals/images/thumb.png',
    'callback' => array(
        'path' => 'application/modules/Pulse/settings/install.php',
        'class' => 'Pulse_Installer',
    ),
    'actions' =>
    array(
        0 => 'install',
        1 => 'upgrade',
        2 => 'refresh',
        3 => 'enable',
        4 => 'disable',
    ),
    'directories' =>
    array(
      'application/modules/Pulse',
      'application/themes/pulse',
    ),
    'files' =>
    array(
      'application/languages/en/pulse.csv',
    ),
  ),
  'items' => array(
    'pulse_customthemes',
  ),
  //Load by default css / js file ------------------------------------------------------------------
  'loadDefault' => array(
    "js" => array(
    ),
    'css' => array(
    )
  ),
	// Hooks ---------------------------------------------------------------------
	'hooks' => array(
		array(
			'event' => 'onRenderLayoutDefault',
			'resource' => 'Pulse_Plugin_Core'
		),
		array(
			'event' => 'onRenderLayoutDefaultSimple',
			'resource' => 'Pulse_Plugin_Core'
		),
	),
);
