<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/
?>
<?php include APPLICATION_PATH .  '/application/modules/Pulse/views/scripts/_adminHeader.tpl';?>

<div class='clear'>
  <div class='settings'>
    <?php echo $this->form->render($this); ?>
  </div>
</div>
<script type="application/javascript">
  scriptJquery('.core_admin_main_pulse').parent().addClass('active');
  
  en4.core.runonce.add(function() {
    showFooterLogo("<?php echo Engine_Api::_()->getApi('settings', 'core')->getSetting('pulse.footer.enablelogo', 1); ?>");
  });
  
  function showFooterLogo(value) {
    if(value == 1) {
      scriptJquery('#pulse_footer_logo-wrapper').show();
      scriptJquery('#pulse_footer_logocontrast-wrapper').show();
    } else {
      scriptJquery('#pulse_footer_logo-wrapper').hide();
      scriptJquery('#pulse_footer_logocontrast-wrapper').hide();
    }
  }
</script>
