<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/
?>

<?php $allParams = $this->allParams; ?>
<div class="pulse_landingpage_service">
  <div class="container">
    <div class="pulse_landingpage_service_row">
      <div class="col-lg-5 col-md-12 col-12 pulse_landingpage_service_left">
        <?php if ($allParams['title']) { ?>
          <h3 class="pulse_title"><?php echo $this->translate($allParams['title']); ?></h3>
        <?php } ?>
        <?php if ($allParams['description']) { ?>
          <p class="pulse_descrption"><?php echo $this->translate($allParams['description']); ?></p>
        <?php } ?>
      </div>
      <div class="col-lg-7 col-md-12 col-12 pulse_landingpage_service_carousel">
        <?php for ($i = 1; $i <= 6; $i++) { ?>
        <?php if (!empty($allParams['photo' . $i]) || !empty($allParams['servicesheading' . $i]) || !empty($allParams['headinglink' . $i]) || !empty($allParams['servicesdescription' . $i])) { ?>
          <div class="pulse_landingpage_service_inner">
            <a <?php if (!empty($allParams['link' . $i])) { ?> href="<?php echo $allParams['link' . $i]; ?>" <?php } else { ?> href="javascript:void(0);" <?php } ?>>
              <div class="pulse_landingpage_service_content">
                <?php if (!empty($allParams['servicesheading' . $i])) { ?>
                  <h4>
                    <?php echo $this->translate($allParams['servicesheading' . $i]); ?>
                  </h4>
                <?php } ?>
                <?php if (!empty($allParams['servicesdescription' . $i])) { ?>
                  <p><?php echo $this->translate($allParams['servicesdescription' . $i]); ?></p>
                <?php } ?>
              </div>
              <figure>
                <?php if(!empty($allParams['photo' . $i])) { ?>
                  <?php $path = Engine_Api::_()->core()->getFileUrl($allParams['photo' . $i], true); ?>
                  <img src="<?php echo $path['image']; ?>" height="" width="" alt="<?php echo $path['alt_text'] ? $path['alt_text'] : 'Services Images'; ?>" />
                <?php } else { ?>
                  <img src="<?php echo 'application/modules/Pulse/externals/images/services/' . $i . '.png'; ?>" height="" width="" alt="Services Images" />
                <?php } ?>
              </figure>
            </a>
          </div>
        <?php } ?>
      <?php } ?>
      </div> 
    </div>
  </div>
</div>

<script type="text/javascript">
owlJqueryObject(".pulse_landingpage_service_carousel").owlCarousel({
    loop:false,
    responsiveClass:true,
    autoWidth:true,
    nav:true,
    dots:false,
    <?php 
      $orientation = ($this->layout()->orientation == 'right-to-left' ? 'rtl' : 'ltr');
      if($orientation == 'rtl') { ?>
        rtl:true,
    <?php } ?>
    responsive:{
        0:{
            nav:false,
            dots:true
        },
        768:{
            nav:true,
            dots:false
        }
    }
});
owlJqueryObject(".owl-prev").html('<i class="fa fa-angle-left"></i>');
owlJqueryObject(".owl-next").html('<i class="fa fa-angle-right"></i>');
</script>
