<?php 
/**
 * Ahead WebSoft Technologies Pvt Ltd.
 * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
 * @license    https://www.socialengine.com/policies
*/
?>
<?php $allParams = $this->allParams; ?>
<div class="pulse_lp_articles">
  <div class="container">
  <div class="pulse_lp_articles_section">
      <div class="pulse_lp_head">
        <?php if ($allParams['title']) { ?>
          <h3 class="pulse_title"><?php echo $this->translate($allParams['title']); ?></h3>
        <?php } ?>
      </div>
      <div class="pulse_lp_article_row">
        <?php foreach( $this->paginator as $item ): ?>
          <div class="pulse_lp_article_card_outer">
            <div class="pulse_lp_article_card">
              <div class="pulse_lp_article_card_image">
                <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.profile')) ?>
              </div>
              <div class="pulse_lp_article_card_content">
                <h6 class="lp_article_title"><?php echo $this->htmlLink($item->getHref(), $item->getTitle()) ?></h6>
                <p class="lp_article_des"><?php echo $this->string()->truncate($this->string()->stripTags($item->body), 50) ?></p>
                <p class="lp_article_date"><?php echo $this->timestamp(strtotime($item->creation_date)) ?></p>
                <a href="<?php echo $item->getHref(); ?>" class="lp_article_btn"><?php echo $this->translate('Read More'); ?></a>
              </div>
            </div>
          </div>
        <?php endforeach; ?>
      </div>
    </div>
  </div>
</div> 
