

/* Landing Page 2 CSS  */
.pulse_landingpage_2{
  background-color:var(--theme-list-background-color); 
}
#global_page_core-index-index.pulse_landingpage_2 .layout_middle > .generic_layout_container{
  background:none;
  padding:0;
  border:0;
  box-shadow:none;
}
#global_page_core-index-index.pulse_landingpage_2 #global_content .layout_main{
  margin:0;
}
.pulse_landingpage_2 #global_wrapper{
  padding:0;
  margin-left:0;
}
[dir="rtl"] .pulse_landingpage_2 #global_wrapper{
  margin-right:0;
  margin-left:auto;
}
.pulse_landingpage_2 .layout_middle{
  padding:0;
}
.pulse_landingpage_2 #global_header,
.pulse_landingpage_2 #global_footer{
  display:none;
}
.pulse_landingpage_2 .layout_pulse_landing_page_main{
  margin-bottom:0;
  border-radius:0 !important;
  background-color:transparent;
}
.pulse_lp_main{
  display:flex;
  flex-direction:column;
  justify-content:space-between;
  gap:30px;
  padding:30px;
}
.pulse_lp_main .pulse_lp_main_inner{
  display:flex;
  justify-content:center;
  align-items:center;
  gap:3.125rem;
  position:relative;
}
.pulse_lp_main .pulse_lp_main_left{
  flex:1;
}
.pulse_lp_main .header_logo,
.pulse_lp_main .header_logo_contrast {
  position:absolute;
  top:0;
}
.pulse_lp_main .pulse_lp_main_logo{
  display:flex;
  justify-content:center;
  align-items:center;
}
.pulse_lp_main .pulse_lp_main_logo a:has(img){
  height:2.8125rem;
}
.pulse_lp_main .pulse_lp_main_logo a:not(img){
  font-size:var(--theme-headline-size-large);
  font-weight:600;
  color:var(--theme-font-color);
}
.pulse_lp_main .pulse_lp_main_logo a img{
  height:100%;
}
.pulse_lp_main .pulse_lp_main_left .user_login_page .user_login_form{
  border:0;
  padding:0;
  width:85%;
  margin:auto;
  display:flex;
  justify-content:center;
  align-items:center;
  gap:3.125rem;
  flex-direction:column;
}
.pulse_lp_main .pulse_lp_main_form{
  width:100%;
  text-align:center;
}
.pulse_lp_main .input-icon{
  position:relative;
}
.pulse_lp_main .input-icon i{
  position:absolute;
  left:15px;
  top:50%;
  font-size:16px;
  transform:translateY(-50%);
  color:var(--theme-font-color-light);
}
[dir="rtl"] .pulse_lp_main .input-icon i{
  right:15px;
  left:auto;
}
.pulse_lp_main .input-icon input{
  padding-inline:2.8125rem !important;
}
.pulse_lp_main .user_login_page #user_form_login .user_showhidepassword > i{
  margin-top:-2.125rem;
  right:5px;
  position:absolute;
}
[dir="rtl"] .pulse_lp_main .user_login_page #user_form_login .user_showhidepassword > i{
  left:5px;
  right:auto;
}
.pulse_lp_main .user_login_page #user_form_login #sociallinks-wrapper{
  margin-block:5px 20px;
}
.pulse_lp_main #user_form_login #fieldset-sociallinks .social_login_btn span{
  display:block;
}
.pulse_lp_main #sociallinks-wrapper{
  display:flex;
  flex-direction:column;
  gap:15px;
}
.pulse_lp_main #sociallinks-wrapper > .form-element > .social_login_btn{
  display:flex;
  border-radius:10px;
  padding:8px 12px;
  border:1px solid var(--theme-input-border-color);
  transition:background-color 0.6s ease;
}
.pulse_lp_main #sociallinks-wrapper > .form-element > .social_login_btn:hover{
  background-color:var(--theme-secondary-button-background-color);
}
.pulse_lp_main #user_form_login #fieldset-sociallinks > .form-element{
  width:100% !important;
}
.pulse_lp_main .social_login_btn > i{
  height:30px;
  width:30px;
}
.pulse_lp_main .social_login_btn > i svg{
  height:16px;
  width:16px;
}
.pulse_lp_main .pulse_lp_main_form .signip_link a{
  font-weight:600;
}
.pulse_lp_main .facebook_login_btn{
  background-color:transparent;
}
.pulse_lp_main .facebook_login_btn > i{
  border-radius:50%;
  background-color:#0866ff;
}
.pulse_lp_main .google_login_btn{
  background:transparent;
}
.pulse_lp_main .linkedin_login_btn{
  background:transparent;
}
.pulse_lp_main .linkedin_login_btn > i{
  border-radius:50%;
  background-color:#0076b0;
}
.pulse_lp_main .twitter_login_btn{
  background:transparent;
}
.pulse_lp_main .twitter_login_btn > i{
  border-radius:50%;
  background-color:#000000;
}
.pulse_lp_main .telegram_login_btn{
  background:transparent;
}
.pulse_lp_main .telegram_login_btn > i{
  border-radius:50%;
  background-color:#000000;
}
.pulse_lp_main .social_login_btn > span{
  font-weight:500;
  padding:0;
  text-align:center;
  color:var(--theme-font-color) !important;
}
.pulse_lp_main .lp2_sep{
  text-align:center;
  position:relative;
  margin-block:20px;
}
.pulse_lp_main .lp2_sep:before{
  position:absolute;
  content:"";
  top:45%;
  left:0;
  width:100%;
  height:1px;
  background:var(--theme-input-border-color);
  transform:translateY(-50%);
  z-index:0;
}
.pulse_lp_main .lp2_sep p{
  display:inline-block;
  font-weight:500;
  padding:0 10px;
  position:relative;
  z-index:1;
  margin-bottom:0;
  color:var(--theme-font-color-light);
  background:var(--theme-list-background-color);
}
.pulse_lp_main .pulse_lp_main_form_heading{
  font-size:var(--theme-headline-size-large);
  font-weight:600 !important;
  text-align:center;
  margin:0 0 30px !important;
  padding:0 !important;
  border-width:0;
  text-transform:capitalize;
  color:var(--theme-font-color);
}
.pulse_lp_main .pulse_lp_main_right{
  width:50%;
  background-size:cover;
  background-repeat:no-repeat;
  background-position:center;
  height:calc(100vh - 115px);
  height:auto;
  min-height:700px;
  display:flex;
  justify-content:flex-end;
  align-items:flex-end;
  flex-direction:column;
  gap:25px;
  border-radius:1.25rem;
  padding:1.25rem 1.25rem 3.125rem 1.25rem;
  position:relative;
}
.pulse_lp_main .pulse_lp_main_right::before{
  content:'';
  position:absolute;
  top:0;
  left:0;
  height:100%;
  width:100%;
  background-color:rgba(0, 0, 0,0.3);
  z-index:2;
  border-radius:1.25rem;
}
.pulse_lp_main .pulse_lp_main_right_content{
  display:flex;
  flex-direction:column;
  justify-content:center;
  position:relative;
  z-index:3;
  width:100%;
}
.pulse_lp_title{
  font-size:var(--theme-headline-size-large);
  font-weight:600;
  margin-bottom:0.9375rem;
  padding:0;
  color:#fff;
}
.pulse_heading{
  font-size:2.1875rem;
  font-weight:600;
  padding:0;
  margin-bottom:0.9375rem;
  color:#fff;
}
.pulse_description{
  font-size:var(--theme-font-size);
  font-weight:400;
  line-height:150%;
  padding:0;
  margin-bottom:0.9375rem;
  color:#fff;
}
.pulse_lp_main_right .pulse_landingpage_app_links{
	display:flex;
	gap:15px;
}
.pulse_lp_main_right .pulse_landingpage_app_links a{
  width:160px;
}
.pulse_lp_main_right .pulse_landingpage_app_links img{
	width:100%;
  height:100%;
}
.pulse_lp_main_right .pulse_lp_switcher{
  z-index:99;
  cursor:pointer;
}
.pulse_lp_main_right .pulse_lp_switcher #thememodetoggle{
  position:relative;
}
.pulse_lp_main_right .pulse_lp_switcher input#theme_toggle{
  position:absolute;
  width:100%;
  height:100%;
  margin:0;
  opacity:0;
  visibility:hidden;
}
.pulse_lp_main_right .pulse_lp_switcher li .contrastmode_toggle{
  background-color:var(--theme-list-background-color-hover);
  border-width:0.0625rem;
  border-radius:1.25rem;
  height:38px;
  width:70px;
  position:relative;
  display:flex;
  align-items:center;
  justify-content:space-between;
  padding:0 0.0625rem;
}
.pulse_lp_main_right .pulse_lp_switcher li .contrastmode_toggle:before{
  content:"";
  background-color:var(--theme-link-color);
  border-radius:50%;
  width:45%;
  aspect-ratio:1;
  position:absolute;
  left:0.125rem;
  top:3px;
}
[dir="rtl"] .pulse_lp_main_right .pulse_lp_switcher  li .contrastmode_toggle:before{
  left:auto;
  right:0.125rem;
}
.pulse_lp_main_right .pulse_lp_switcher li .contrastmode_toggle i{
  width:50%;
  height:1.875rem;
  font-size:12px;
  display:flex;
  align-items:center;
  justify-content:center;
  position:relative;
  z-index:1;
  cursor:pointer;
}
.pulse_lp_main_right .pulse_lp_switcher li input[type="checkbox"]:checked + .contrastmode_toggle{
  background-color:var(--theme-button-background-color);
}
.pulse_lp_main_right .pulse_lp_switcher li .contrastmode_toggle._light > i:nth-child(1),
.pulse_lp_main_right .pulse_lp_switcher li .contrastmode_toggle._dark > i:nth-last-child(1){
  color:var(--theme-button-font-color) !important;
}
.pulse_lp_main_right .pulse_lp_switcher li input[type="checkbox"]:checked + .contrastmode_toggle:before{
  right:3px;
  left:auto;
  background-color:var(--theme-link-color);
}
[dir="rtl"] .pulse_lp_main_right .pulse_lp_switcher li input[type="checkbox"]:checked + .contrastmode_toggle:before{
  left:0.125rem;
  right:auto;
}
.pulse_lp_footer .pulse_lp_footer_inner{
  display:flex;
  justify-content:space-between;
  align-items:center;
  gap:0.625rem;
  padding:0px;
}
.pulse_lp_footer .pulse_lp_footer_left{
  font-weight:500 !important;
  display:flex;
  align-items:center;
  justify-content:flex-start;
  flex-wrap:wrap;
  font-size:var(--theme-font-size-small);
}
.pulse_lp_footer .pulse_lp_footer_right{
  display:flex;
  justify-content:flex-start;
  align-items:center;
  gap:30px;
}
.pulse_lp_footer .pulse_lp_footer_right_menu{
  display:flex;
  gap:30px;
}
.pulse_lp_footer .pulse_lp_footer_right .menu_core_footer{
  font-size:var(--theme-font-size-small);
  font-weight:500;
  text-decoration:none;
  color:var(--theme-font-color);
}
.pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item{
  position:relative;
}
.pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item:first-child:before{
  display:none;
}
.pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item:before{
  content:"";
  position:absolute;
  top:45%;
  left:-16px;
  height:5px;
  width:5px;
  background-color:var(--theme-font-color);
  border-radius:50%;
}
[dir="rtl"] .pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item:before{
  top:45%;
  left:auto;
  right:-19px;
}
.pulse_lp_footer .pulse_lp_footer_right .language_chooser .language_chooser_btn{
  font-size:var(--theme-font-size-small);
  font-weight:500;
  display:inline-flex;
  align-items:center;
  border-radius:0;
  border:0;
  padding:0;
  color:var(--theme-font-color);
}
.pulse_lp_footer .pulse_lp_footer_right_language{
  position:relative;
}
.pulse_lp_footer .pulse_lp_footer_right_language:before{
  content:"";
  position:absolute;
  top:45%;
  left:-16px;
  height:5px;
  width:5px;
  background-color:var(--theme-font-color);
  border-radius:50%;
}
[dir="rtl"] .pulse_lp_footer .pulse_lp_footer_right_language:before{
  top:40%;
  left:auto;
  right:-17px;
}
.pulse_lp_footer .pulse_lp_footer_right_language:not(.language_chooser){
  display:none;
}
.pulse_lp_footer .pulse_lp_footer_right_language:has(.language_chooser){
  display:block;
}
.pulse_lp_footer .pulse_lp_footer_right_language:not(.language_chooser):before{
  display:none;
}
.pulse_lp_footer .pulse_lp_footer_right_language:has(.language_chooser):before{
  display:block;
}
@media (max-width:767px){
  .pulse_lp_main .input-icon i {
    top:45%;
  }
  .pulse_landingpage_2 .pulse_lp_main{
    height:auto;
    gap:30px;
  }
  .pulse_lp_footer .pulse_lp_footer_inner {
    flex-direction:column;
    gap:10px;
  }
  .pulse_lp_footer .pulse_lp_footer_right {
    justify-content:center;
    flex-wrap:wrap;
    gap:10px 20px;
  }
  .pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item:before {
    display:none;
  }
  .pulse_lp_footer .pulse_lp_footer_right_language:before {
    display:none !important;
  }
  .pulse_lp_main .pulse_lp_main_inner{
    flex-direction:column;
    gap:1.875rem;
  }
  .pulse_lp_main .pulse_lp_main_left{
    width:100%;
  }
  .pulse_lp_main .pulse_lp_main_left .user_login_page .user_login_form{
    width:100%;
    gap:1.875rem;
  }
  .pulse_lp_main .header_logo,
  .pulse_lp_main .header_logo_contrast {
    position:inherit;
  }
  .pulse_lp_main .pulse_lp_main_logo a{
    height:2.1875rem;
  }
  .pulse_lp_main .pulse_lp_main_right{
    width:100%;
    flex-direction:column;
    justify-content:flex-end;
    gap:15px;
    display:none;
  }
  .pulse_lp_main .pulse_lp_main_right .pulse_lp_title{
    font-size:var(--theme-headline-size-medium);
  }
  .pulse_lp_main .pulse_lp_main_right .pulse_heading{
    font-size:var(--theme-headline-size-medium);
  }
  .pulse_lp_main .pulse_lp_main_right .pulse_description{
    font-size:var(--theme-font-size-small);
  }
  .pulse_lp_main .pulse_lp_main{
    padding:3.125rem 1.25rem 1.25rem 1.25rem;
  }
  .pulse_lp_main_left .user_login_page .user_login_form{
    width:100%;
    padding:0 !important;
  }
  .pulse_lp_main .pulse_landingpage_app_links{
    justify-content:flex-start;
  }
  .pulse_lp_main .pulse_landingpage_app_links img{
    max-width:100%;
    max-height:inherit;
  }
  .pulse_lp_main .pulse_lp_footer_right .menu_core_footer:before{
    display:none;
  }
}

@media (max-width:991px) {
  .pulse_lp_footer .pulse_lp_footer_inner {
    flex-direction:column;
    gap:10px;
  }
  .pulse_lp_footer .pulse_lp_footer_right {
    justify-content:center;
    flex-wrap:wrap;
    gap:10px 20px;
  }
  .pulse_lp_footer .pulse_lp_footer_right .lp_footer_menu_item:before {
    display:none;
  }
  .pulse_lp_footer .pulse_lp_footer_right_language:before {
    display:none !important;
  }
}

@media (min-width:1920px){
  #global_page_core-index-index #global_content{
    width:var(--theme-content-width);
  }
  .pulse_landingpage_2 .layout_pulse_landing_page_main{
    min-height:100dvh;
    display:flex;
    justify-content:center;
    align-items:center;
  }
  .pulse_landingpage_2 .pulse_lp_main_inner{
    max-height:900px;
  }
  .pulse_landingpage_2 .pulse_lp_main_right{
    height:750px;
  }
}


/* Landing Page 1 Css */
:root{
  --pulse-lp1-section-spacing:60px;
}
#global_page_core-index-index.pulse_landingpage_1 .layout_middle > .generic_layout_container{
  background:none;
  padding:0;
  border:0;
  margin:0;
  box-shadow:none;
}
#global_page_core-index-index #global_content .layout_main{
  display:inherit;
}
.container{
	max-width:var(--theme-main-width);
}
.pulse_title{
	font-size:2.1875rem;
	font-weight:700 !important;
	padding:0;
	margin-bottom:1.5625rem;
  color:var(--theme-font-color);
  line-height:130%;
}
.pulse_descrption{
  font-size:1.125rem;
  font-weight:400;
  margin-bottom:0.625rem;
  line-height:150%;
  color:var(--theme-font-color);
}
.pulse_lp_banner .container,
.pulse_landingpage_features .container,
.pulse_lp_cta_section .container,
.pulse_landingpage_service .container,
.pulse_lp_articles .container,
.layout_pulse_landing_page_app_section .container {
  padding:0;
}
@media (max-width:767px){
  :root{
    --pulse-lp1-section-spacing:40px;
  }
  .pulse_title {
    font-size:22px;
    font-weight:600 !important;
    line-height:140%;
  }
  #global_page_core-index-index div#global_wrapper{
    padding-top:0;
  }
  #global_page_core-index-index #global_content .layout_main{
    margin-inline:0;
  }
}
@media (min-width:768px) and (max-width:1199px){
  .pulse_landingpage_app_section{
    margin-bottom:-100px;
  }
}
@media (max-width:1199px){
  #global_page_core-index-index.pulse_landingpage_1 .header_main_menu_toggle{
    display:none !important;
  }
}

/* Landing Page Banner Section CSS */
.pulse_landingpage_1 .layout_page_header{
  box-shadow:none;
}
.pulse_lp_banner_section{
  padding:3.125rem 1.875rem 1.875rem 1.875rem;
  border-radius:var(--themewidget-radius);
  background-color:var(--theme-color);
  margin-top:20px;
  /* background-color:#141B34; */
}
html.dark_mode .pulse_lp_banner_section{
  background-color:var(--theme-list-background-color);
}
.pulse_lp_banner_section_row{
  display:flex;
  justify-content:flex-start;
  align-items:flex-start;
}
.pulse_lp_banner .pulse_title{
  font-size:80px;
  color:var(--theme-button-font-color);
  color:#fff;
}
.pulse_lp_banner .pulse_description{
  font-size:1.125rem;
  color:var(--theme-button-font-color);
  color:#fff;
}
.pulse_lp_banner_counter{
  display:flex;
  align-items:flex-start;
  justify-content:center;
  flex-wrap:wrap;
  margin:3.125rem 0rem 0rem 0rem;
}
.pulse_lp_banner_counter li{
  padding:0.625rem 0.625rem 0rem;
  width:24%;
}
.pulse_lp_banner_counter li h4{
  font-size:var(--theme-headline-size-large);
  font-size:1.875rem;
  font-weight:700;
  border:0;
  margin-bottom:0.75rem;
  padding:0;
  color:var(--theme-button-font-color);
  color:#fff;
}
/* html.dark_mode .pulse_lp_banner_counter li h4{
  color:#fff;
} */
.pulse_lp_banner_counter li p{
 font-size:1.125rem;
 font-weight:400;
  margin-bottom:0;
  color:var(--theme-button-font-color);
  color:#fff;
}
/* html.dark_mode .pulse_lp_banner_counter li p {
  color:#fff;
} */
.pulse_lp_banner_section_row figure{
  position:relative;
  margin-top:-4.375rem;
  height:25rem;
}
.pulse_lp_banner_section_row figure img{
  height:100%;
}
.pulse_lp_banner_counter_btn{
  margin-top:5rem;
  display:inline-block;
}
.pulse_lp_banner_counter_btn .btn{
  font-size:var(--theme-font-size);
  font-size:1rem;
  font-weight:600;
  display:flex;
  justify-content:center;
  align-items:center;
  height:2.8125rem;
  min-width:12.5rem;
  border-width:0!important;
  padding:0.625rem;
  border-radius:0.75rem;
  background-color:#EAFF46 !important;
  color:var(--theme-font-color) !important;
  color:#0C1014 !important;
  transform:translate(0px);
  transition:all 0.8s ease;
}
.pulse_lp_banner_counter_btn .btn:hover{
  background-color:#d0e52b !important;
}
html.dark_mode .pulse_lp_banner_counter_btn .btn:hover{
  color:#0C1014 !important;
}
/* Banner animations */
.pulse_lp_banner .pulse_title,
.pulse_lp_banner .pulse_description,
.pulse_lp_banner_counter li {
  opacity:0;
  transform:translateY(50px);
  animation:fadeUp 0.6s ease forwards;
}
.pulse_lp_banner .pulse_title { animation-delay:0.2s; }
.pulse_lp_banner .pulse_description { animation-delay:0.4s; }
.pulse_lp_banner_counter li:nth-child(1) { animation-delay:0.6s; }
.pulse_lp_banner_counter li:nth-child(2) { animation-delay:0.7s; }
.pulse_lp_banner_counter li:nth-child(3) { animation-delay:0.8s; }
.pulse_lp_banner_counter li:nth-child(4) { animation-delay:0.9s; }
@keyframes fadeUp {
  to {
    opacity:1;
    transform:translateY(0);
  }
}
/* .pulse_lp_banner_section_row figure img {
  animation:bannerfloat 4s ease-in-out infinite;
}
@keyframes bannerfloat {
  0%,100% { transform:translateY(0); }
  50% { transform:translateY(-15px); }
} */
@media (max-width:767px){
  .pulse_lp_banner_section{
    margin-top:0;
  }
  .pulse_lp_banner .container{
    padding:0;
  }
  .pulse_lp_banner_section{
    padding:1.875rem 0.9375rem 2.5rem 0.9375rem;
    border-radius:0;
  }
  .pulse_lp_banner .pulse_title{
    font-size:1.875rem;
    font-weight:700 !important;
    text-align:center;
    margin-bottom:0.9375rem;
  }
  .pulse_lp_banner .pulse_description{
    font-size:var(--theme-font-size-small);
    font-size:0.875rem;
    opacity:0.85;
    text-align:center;
  }
  .pulse_lp_banner_counter{
    margin-top:1.5625rem;
    gap:15px;
  }
  .pulse_lp_banner_counter li{
    min-width:100px;
    max-width:125px;
    padding:0.9375rem 0.5rem;
    text-align:center;
  }
  .pulse_lp_banner_counter li h4{
    font-size:1.25rem;
    font-weight:700;
    margin-bottom:0.5rem;
  }
  .pulse_lp_banner_counter li p{
    font-size:0.8125rem;
    opacity:0.85;
  }
  .pulse_lp_banner_counter_btn{
    margin-top:2rem;
    display:flex;
    justify-content:center;
    align-items:center;
  }
  .pulse_lp_banner_section_row figure{
    display:none;
  }
  .pulse_lp_banner_counter_btn .btn{
    height:3rem;
    border-radius:1rem;
  }
}
@media (max-width:540px){
  .pulse_lp_banner_counter{
    display:grid;
    grid-template-columns: repeat(2, 1fr);
    gap:15px;
  }
  .pulse_lp_banner_counter li{
    width:100%;
    max-width:inherit;
  }
}
@media(min-width:767px) and (max-width:991px){
  .pulse_lp_banner .pulse_title{
    font-size:2.1875rem;
  }
  .pulse_lp_banner .pulse_description{
    font-size:0.875rem;
  }
  .pulse_lp_banner_counter{
    margin:1.25rem 0rem 0rem 0rem;
  }
  .pulse_lp_banner_counter li h4{
    font-size:1.3125rem;
  }
  .pulse_lp_banner_counter li p{
    font-size:0.9375rem;
  }
  .pulse_lp_banner_section_row figure{
    display:none;
  }
  .pulse_lp_banner_counter_btn{
    margin-top:2.1875rem;
  }
  
}
/* Landing Page Banner Section CSS End */

/* Landing Page Features Section CSS  */
.pulse_landingpage_features{
  padding:var(--pulse-lp1-section-spacing) 0px 0;
}
.pulse_landingpage_features .pulse_title {
  text-align:center;
}
.pulse_landingpage_features_row{
  display:flex;
  gap:1.875rem;
}
.pulse_landingpage_features_inner{
  display:flex;
  flex-direction:column;
  justify-content:space-between;
  padding:1.25rem;
  width:33%;
  border-radius:var( --theme-item-radius);
  background-color:rgba(230, 255, 222, 1);
  transition:var(--theme-item-transition);
}

html.dark_mode .pulse_landingpage_features_inner:nth-child(1){
  background-color:rgba(230, 255, 222, 30%);
}
.pulse_landingpage_features_inner:hover{
  box-shadow:var(--theme-layout-box-shadow);
}
.pulse_landingpage_features_inner:nth-child(2){
  background-color:rgba(255, 238, 222, 1);
}
html.dark_mode .pulse_landingpage_features_inner:nth-child(2){
  background-color:rgba(255, 238, 222, 30%);
}
.pulse_landingpage_features_inner:nth-child(3){
  background-color:rgba(222, 234, 255, 1);
}
html.dark_mode .pulse_landingpage_features_inner:nth-child(3){
  background-color:rgba(222, 234, 255, 30%);
}
.pulse_landingpage_features_inner h4{
  font-size:20px;
  font-weight:600!important;
  padding:0;
  margin:0 0 0.625rem;
  border:0;
  color:var(--theme-font-color);
  color:#0C1014;
}
html.dark_mode .pulse_landingpage_features_inner h4{
  color:#fff;
}
.pulse_landingpage_features_inner p{
  font-size:var(--theme-font-size-small);
  font-weight:400;
  margin:0rem 0rem 0.625rem 0rem;
  color:var(--theme-font-color);
  color:#0C1014;
}
html.dark_mode .pulse_landingpage_features_inner p{
  color:#fff;
}
.pulse_landingpage_features_inner figure{
  width:100%;
  margin:1.875rem auto 0rem auto;
}
.pulse_landingpage_features_inner figure img{
  width:100%;
}
@media (max-width:767px){
  .pulse_landingpage_features{
    padding-inline:20px;
  }
  .pulse_landingpage_features_row{
    gap:0.9375rem;
    overflow-x:auto;
    scroll-snap-type:x mandatory;
  }
  .pulse_landingpage_features_inner{
    width:85%;
    min-width:85%;
    scroll-snap-align:start;
    scroll-snap-stop:always;
  }
  .pulse_landingpage_features_inner figure{
    width:100%;
  }
  .pulse_landingpage_features_inner h4{
    font-size:var(--theme-headline-size-medium);
  }
}
@media(min-width:767px) and (max-width:991px){
  .pulse_landingpage_features_inner{
    width:32%;
  }
  .pulse_landingpage_features_row{
    gap:0.9375rem;
  }
  .pulse_landingpage_features_inner h4{
    font-size:var(--theme-headline-size-medium);
    line-height:130%;
  }
  .pulse_landingpage_features_inner figure{
    width:12.5rem;
  }
}
/* Landing Page Features Section CSS End */

/* Landing Page CTA Sectiion CSS */
.pulse_lp_cta_section {
  padding:var(--pulse-lp1-section-spacing) 0px 0px;
}
.pulse_lp_cta_section .pulse_title {
  text-align:center;
}
.pulse_lp_cta_row {
  display:grid;
  grid-template-columns:repeat(2,1fr);
  gap:30px;
  position:relative;
}
.pulse_lp_cta_row:after {
  position:absolute;
  content:"";
  top:50%;
  left:50%;
  height:300px;
  width:300px;
  transform:translate(-50%,-50%);
  background-image:url(cta-bg.png);
  background-size:cover;
  background-position:center;
  background-repeat:no-repeat;
}
.pulse_lp_cta_card {
  display:flex;
  align-items:center;
  gap:20px;
  padding:30px;
  background-color:var(--theme-list-background-color);
  position:relative;
  z-index:2;
  min-height:160px;
  border-radius:var(--theme-widget-radius);
  /* border:1px solid var(--theme-border-color); */
  box-shadow:var(--theme-item-shadow);
}
.pulse_lp_cta_icon i {
  font-size:35px;
  height:70px;
  width:70px;
  display:flex;
  justify-content:center;
  align-items:center;
  border-radius:15px;
}
.pulse_lp_cta_card:nth-child(1) .pulse_lp_cta_icon i{
  color:#FF3951;
  background-color:#FFEAEA;
}
.pulse_lp_cta_card:nth-child(2) .pulse_lp_cta_icon i{
  color:#3B148A;
  background-color:#E7E2FF;
}
.pulse_lp_cta_card:nth-child(3) .pulse_lp_cta_icon i{
  color:#3F80FD;
  background-color:#DEEBFF;
}
.pulse_lp_cta_card:nth-child(4) .pulse_lp_cta_icon i{
  color:#FF9800;
  background-color:#FFF1E2;
}
.pulse_lp_cta_card h4 {
  font-size:var(--theme-headline-size-medium);
  font-weight:600;
  padding:0px 0px 10px 0px;
  margin:0;
  border:0;
}
.pulse_lp_cta_card p {
  font-size:var(--theme-font-size-small);
  margin:0;
  line-height:20px;
  color:var(--theme-font-color-light);
}
@media (max-width:768px) {
  .pulse_lp_cta_section {
    padding-inline:20px;
  }
  .pulse_lp_cta_row {
    grid-template-columns:repeat(1,1fr);
    gap:15px;
  }
  .pulse_lp_cta_card {
    padding:30px 20px;
    border-radius:var(--theme-item-radius);
  }
  .pulse_lp_cta_row:before {
    display:none;
  }
}
/* Landing Page CTA Section CSS End */

/* Landing Page Services Section CSS */
.pulse_landingpage_service {
  padding:var(--pulse-lp1-section-spacing) 0px 0px;
}
.pulse_landingpage_service_row{
  display:flex;
  justify-content:space-between;
  padding:1.875rem 0rem 1.875rem 1.875rem;
  border-radius:var(--themewidget-radius);
  background-color:var(--theme-list-background-color);
  position:relative;
}
.pulse_landingpage_service_left{
  padding-right:1.875rem;
}
.pulse_landingpage_service_carousel .owl-stage-outer{
  overflow:hidden;
}
.pulse_landingpage_service_carousel .owl-stage{
  display:flex !important;
}
.pulse_landingpage_service_inner{
  display:flex;
  flex-direction:column;
  width:18.75rem;
  height:21.875rem;
  margin:1.875rem 1.25rem 1.875rem 0;
  border-radius:0.75rem;
  padding:1.25rem;
  transition:var(--theme-item-transition);
  background-color:var(--theme-list-background-color-alt);
}
[dir="rtl"] .pulse_landingpage_service_inner{
  margin:1.875rem 0 1.875rem 1.25rem;
}
.pulse_landingpage_service_inner:hover{
  box-shadow:var(--theme-layout-box-shadow);
}
.pulse_landingpage_service_inner:nth-child(1){
  margin-left:10px;
}
.pulse_landingpage_service_inner a{
  display:flex;
  flex-direction:column;
  justify-content:space-between;
  height:100%;
}
.pulse_landingpage_service_carousel h4{
	font-size:20px;
	padding:0;
	margin-bottom:0.625rem ;
	border:0;
	font-weight:600 !important;
}
.pulse_landingpage_service_carousel p{
	font-size:var(--theme-font-size-small);
	margin-bottom:0.625rem;
  color:var(--theme-font-color);
}
.pulse_landingpage_service_inner figure{
  width:100%;
  margin-inline:auto;
  margin-bottom:0;
}
.pulse_landingpage_service_inner figure img{
  width:100%;
}
.pulse_landingpage_service_carousel .owl-nav > div{
  width:2.5rem;
  height:2.5rem;
  color:var(--theme-button-background-color);
  background-color:var(--theme-list-background-color);
  border-radius:50%;
  display:flex;
  justify-content:center;
  align-items:center;
  box-shadow:0 0 .3125rem rgba(0,0,0,.2);
  position:absolute;
  z-index:1;
  bottom:1.875rem;
  font-size:1.125rem;
}
[dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div{
  transform:rotate(180deg);
}
.pulse_landingpage_service_carousel .owl-nav > div.owl-next{
  left:5.9375rem;
  cursor:pointer !important;
}
[dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-next{
  right:5.9375rem;
  cursor:pointer !important;
  left:auto;
}
.pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
  left:1.875rem;
  cursor:pointer !important;
}
[dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
  right:1.875rem;
  left:auto;
  cursor:pointer !important;
}
.pulse_landingpage_service_carousel .owl-nav > div.disabled{
  cursor:no-drop !important;
  background-color:var(--theme-list-background-color);
  color:#999;  
  box-shadow:none;
}
@media (max-width:767px){
  .pulse_landingpage_service {
    padding-inline:20px;
  }
  .pulse_landingpage_service_row{
    padding:1.875rem 0.9375rem;
    flex-direction:column;
    gap:0.9375rem;
  }
  .pulse_landingpage_service_left{
    padding-right:0;
  }
  .pulse_landingpage_service_left .pulse_title{
    margin-bottom:25px;
    text-align:center;
  }
  .pulse_landingpage_service_left .pulse_descrption{
    font-size:14px;
    margin-bottom:15px;
    text-align:center;
  }
  .pulse_landingpage_service_carousel{
    position:relative;
  }
  .pulse_landingpage_service_carousel .owl-stage{
    gap:15px;
  }
  .pulse_landingpage_service_inner{
    margin:0 0 10px!important;
  }
  .pulse_landingpage_service_carousel h4{
    font-size:var(--theme-headline-size-medium);
  }
  .pulse_landingpage_service_carousel p{
    font-size:var(--theme-font-size-small);
    opacity:0.85;
  }
  .pulse_landingpage_service_inner figure{
    width:100%;
  }
  .pulse_landingpage_service_carousel .owl-nav > div{
    width:2.5rem;
    height:2.5rem;
    color:var(--theme-button-background-color);
    background-color:var(--theme-button-font-color);
    border-radius:50%;
    display:flex;
    justify-content:center;
    align-items:center;
    box-shadow:0 0 .3125rem rgba(0,0,0,.2);
    position:absolute;
    z-index:1;
    font-size:1.125rem;
    transform:translateY(-50%);
    top:50%;
    bottom:auto;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div{
    transform:translateY(-50%) rotate(180deg);
  }
  .pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
    left:0rem;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
    right:0rem;
    left:auto;
  }
  .pulse_landingpage_service_carousel .owl-nav > div.owl-next{
    left:auto;
    right:0;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-next{
    right:auto;
    left:0;
  }
  .pulse_landingpage_service_carousel .owl-nav > div.disabled{
    display:none;
  }
  .pulse_landingpage_service_carousel .owl-nav{
  display:none !important;
  }
  .pulse_landingpage_service_carousel .owl-dots{
    display:flex;
    justify-content:center;
    align-items:center;
    gap:0.375rem;
    padding-top:0.625rem;
  }
  .pulse_landingpage_service_carousel .owl-dot{
    height:10px;
    width:10px;
    border-radius:50%;
    background-color:var(--theme-color);
    background-color:var(--theme-list-background-color-alt);
    border:1px solid var(--theme-border-color);
    transition:all 0.8s ease
  }
  .pulse_landingpage_service_carousel .owl-dot.active{
    width:20px;
    border-radius:20px;
    background-color:var(--pulse-secondary-button-background-color-hover);
  }
}
@media(min-width:767px) and (max-width:991px){
  .pulse_landingpage_service_row{
    flex-direction:column;
    gap:1.875rem;
  }
  .pulse_landingpage_service_carousel{
    position:relative;
  }
  .pulse_landingpage_service_carousel h4{
    font-size:var(--theme-headline-size-medium);
  }
  .pulse_landingpage_service_carousel p{
    font-size:var(--theme-font-size-small);
  }
  .pulse_landingpage_service_carousel .owl-nav > div{
    width:2.5rem;
    height:2.5rem;
    color:var(--theme-button-background-color);
    background-color:var(--theme-button-font-color);
    border-radius:50%;
    display:flex;
    justify-content:center;
    align-items:center;
    box-shadow:0 0 .3125rem rgba(0,0,0,.2);
    position:absolute;
    z-index:1;
    font-size:1.125rem;
    transform:translateY(-50%);
    top:50%;
    bottom:auto;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div{
    transform:translateY(-50%) rotate(180deg);
  }
  .pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
    left:0rem;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-prev{
    right:0rem;
    left:auto;
  }
  .pulse_landingpage_service_carousel .owl-nav > div.owl-next{
    left:auto;
    right:0;
  }
  [dir="rtl"] .pulse_landingpage_service_carousel .owl-nav > div.owl-next{
    right:auto;
    left:0 !important;
  }
  .pulse_landingpage_service_carousel .owl-nav > div.disabled{
    display:none;
  }
}
/* Landing Page Services Section CSS End */

/* Landing Page Blog Section CSS */
.pulse_lp_articles{
  padding:var(--pulse-lp1-section-spacing) 0px 0px;
}
.pulse_lp_article_row{
  display:grid;
  grid-template-columns:repeat(3, 1fr);
  gap:1.875rem;
}
.pulse_lp_article_card_outer{
  width:100%;
  border-radius:0.75rem;
}
.pulse_lp_article_card_outer:hover{
  box-shadow:rgba(99, 99, 99, 0.2) 0rem 0.125rem 0.5rem 0rem;
  box-shadow:var(--theme-item-shadow);
}
.pulse_lp_article_card{
  display:flex;
  flex-direction:column;
  height:100%;
  border-radius:0.75rem;
  background-color:var(--theme-list-background-color);
}
.pulse_lp_article_card_image{
  aspect-ratio:16/9;
}
.pulse_lp_article_card_image .bg_item_photo{
  border-radius:0.75rem;
  border:0;
}
.pulse_lp_article_card_content{
  display:flex;
  flex-direction:column;
  padding:0.9375rem 0.625rem;
  flex:1;
}
.lp_article_title{
  margin-bottom:0.625rem;
}
.lp_article_title a{
  font-size:var(--theme-headline-size-medium);
  font-weight:600;
  color:var(--theme-font-color);
}
.lp_article_des{
  font-size:var(--theme-font-size-small);
  font-weight:400;
  margin-bottom:0.625rem;
  line-height:150%;
  color:var(--theme-font-color);
}
.lp_article_date{
  font-size:var(--theme-font-size-small);
  font-weight:400;
  margin-bottom:0.625rem;
  color:var(--theme-font-color);
}
.lp_article_btn{
  width:8.125rem;
  height:2.375rem;
  display:flex;
  justify-content:center;
  align-items:center;
  border-radius:2.5rem;
  font-size:var(--theme-font-size);
  font-weight:400;
  margin-top:auto;
  cursor:pointer;
  color:var(--theme-button-font-color);
  background-color:var(--theme-button-background-color);
}
.lp_article_btn:hover{
  color:var(--theme-button-font-color);
  background-color:var(--theme-button-background-color-hover);
}
@media (max-width:767px){
  .pulse_lp_articles{
    padding-inline:20px;
  }
  .pulse_lp_article_row{
    display:flex;
    overflow-x:auto;
    scroll-snap-type:x mandatory;
    gap:0.9375rem;
  }
  .pulse_lp_article_card_outer{
    min-width:90%;
    scroll-snap-align:start;
    scroll-snap-stop:always;
  }
  .pulse_lp_articles_section .pulse_title{
    font-size:22px;
    font-weight:600 !important;
    margin-bottom:25px;
    text-align:center;
  }
  .lp_article_date{
    opacity:0.7;
  }
  .lp_article_date{
    font-size:0.75rem;
    opacity:0.7;
  }
  .lp_article_btn{
    font-size:0.8125rem;
    height:2.25rem;
  }
}
/* Landing Page Blog Section CSS End */

/* Landing Page App Section CSS */
.layout_pulse_landing_page_app_section{
  margin-top:calc(var(--theme-widget-spacing) + 3.125rem);
}
.layout_pulse_landing_page_app_section .container {
  padding:0;
}
.pulse_landingpage_app_section{
  border-radius:var(--themewidget-radius);
  background-color:var(--theme-list-background-color);
  border-width:1px;
  display:flex;
  align-items:center;
  justify-content:flex-start;
  overflow:visible;
  position:relative;
  z-index:1;
  margin-top: 6.25rem;
  margin-bottom:-11.25rem;
}
.pulse_landingpage_app_left{
	flex:1;
  padding:0.625rem 1.875rem;
}
.pulse_landingpage_app_section h3{
	font-size:2.1875rem;
	font-weight:700 !important;
	margin-bottom:0.625rem;
	padding:0;
  line-height:130%;
  color:var(--theme-font-color);
}
.pulse_landingpage_app_section p{
	font-size:var(--theme-font-size-small);
	margin-bottom:0;
	line-height:1.5rem;
  color:var(--theme-font-color);
}
.pulse_landingpage_app_section .pulse_landingpage_app_links{
	display:flex;
	align-items:center;
	justify-content:flex-start;
  gap:1.25rem;
	margin:1.875rem 0rem 0rem 0rem;
}
.pulse_landingpage_app_right{
	width:26.875rem;
  margin-top:-3.125rem;
}
.pulse_landingpage_app_right img{
	height:auto;
	width:auto;
	max-width:100%;
}
@media (max-width:767px){
  .layout_pulse_landing_page_app_section{
    margin-top:0;
  }
  .pulse_landingpage_app_section{
    padding:1.875rem 0.9375rem;
    flex-direction:column-reverse;
    gap:1.875rem;
    margin:40px 20px -100px 20px;
  }
  .pulse_landingpage_app_left{
    text-align:center;
    padding:0;
  }
  .pulse_landingpage_app_section h3{
    font-size:22px;
    font-weight:700 !important;
    line-height:130%;
    padding-inline:0.625rem;
  }
  .pulse_landingpage_app_section p{
    opacity:0.9;
    line-height:inherit;
    padding-inline:0.625rem;
  }
  .pulse_landingpage_app_links{
    justify-content:center !important;
    gap:1.25rem;
  }
  .pulse_landingpage_app_links img{
    max-height:2.5rem;
    max-width:7.5rem;
  }
  .pulse_landingpage_app_right{
    width:50%;
    margin-top:-4.375rem;
    display:none;
  }
}
/* Landing Page App Section CSS End */

/* Landing Pager Footer Section CSS */
#global_page_core-index-index #global_content .layout_main .layout_middle{
  overflow:visible;
}
#global_page_core-index-index .pulse_footer{
  padding-top:11.875rem;
}
@media (max-width:767px){
  #global_page_core-index-index .pulse_footer{
    padding-top:7.5rem;
  }
}
/* Landing Pager Footer Section CSS End */